@@ -85,31 +85,6 @@ use Time::HiRes qw( usleep );
 # this script is reload at every command ,if i want the button on/off (Focus MAN) for OSD works...
 my $osd = "on";
 
-sub new
-{
-    my $class = shift;
-    my $id = shift;
-    my $self = ZoneMinder::Control->new( $id );
-    bless( $self, $class );
-    srand( time() );
-    return $self;
-}
-
-our $AUTOLOAD;
-
-sub AUTOLOAD
-{
-    my $self = shift;
-    my $class = ref($self) || croak( "$self not object" );
-    my $name = $AUTOLOAD;
-    $name =~ s/.*://;
-    if ( exists($self->{$name}) )
-    {
-        return( $self->{$name} );
-    }
-    Fatal( "Can't access $name member of object of class $class" );
-}
-
 sub open
 {
     my $self = shift;
@@ -120,12 +95,6 @@ sub open
     $self->{state} = 'open';
 }
 
-sub close
-{
-    my $self = shift;
-    $self->{state} = 'closed';
-}
-
 sub printMsg
 {
     my $self = shift;
