@@ -21,14 +21,12 @@
 #define ZM_FFMPEG_H
 #include <stdint.h>
 #include "zm.h"
-#include "zm_image.h"
 
-#ifdef __cplusplus
 extern "C" {
-#endif
 
 // AVUTIL
 #if HAVE_LIBAVUTIL_AVUTIL_H
+#include "libavutil/avassert.h"
 #include <libavutil/avutil.h>
 #include <libavutil/base64.h>
 #include <libavutil/mathematics.h>
@@ -40,8 +38,8 @@ extern "C" {
  * b and c the minor and micro versions of libav
  * d and e the minor and micro versions of FFmpeg */
 #define LIBAVUTIL_VERSION_CHECK(a, b, c, d, e) \
-  ( (LIBAVUTIL_VERSION_MICRO <  100 && LIBAVUTIL_VERSION_INT >= AV_VERSION_INT(a, b, c) ) || \
-    (LIBAVUTIL_VERSION_MICRO >= 100 && LIBAVUTIL_VERSION_INT >= AV_VERSION_INT(a, d, e) ) )
+    ( (LIBAVUTIL_VERSION_MICRO <  100 && LIBAVUTIL_VERSION_INT >= AV_VERSION_INT(a, b, c) ) || \
+      (LIBAVUTIL_VERSION_MICRO >= 100 && LIBAVUTIL_VERSION_INT >= AV_VERSION_INT(a, d, e) ) )
 
 #if LIBAVUTIL_VERSION_CHECK(50, 29, 0, 29, 0)
 #include <libavutil/opt.h>
@@ -58,55 +56,55 @@ extern "C" {
 #include <ffmpeg/mathematics.h>
 #include <ffmpeg/opt.h>
 #endif /* HAVE_LIBAVUTIL_AVUTIL_H */
-  
+    
 #if defined(HAVE_LIBAVUTIL_AVUTIL_H) 
 #if LIBAVUTIL_VERSION_CHECK(51, 42, 0, 74, 100)
-  #define _AVPIXELFORMAT AVPixelFormat
+    #define _AVPIXELFORMAT AVPixelFormat
 #else
-  #define _AVPIXELFORMAT PixelFormat
-  #define AV_PIX_FMT_NONE PIX_FMT_NONE
-  #define AV_PIX_FMT_RGB444 PIX_FMT_RGB444
-  #define AV_PIX_FMT_RGB555 PIX_FMT_RGB555
-  #define AV_PIX_FMT_RGB565 PIX_FMT_RGB565
-  #define AV_PIX_FMT_BGR24 PIX_FMT_BGR24
-  #define AV_PIX_FMT_RGB24 PIX_FMT_RGB24
-  #define AV_PIX_FMT_BGRA PIX_FMT_BGRA
-  #define AV_PIX_FMT_ARGB PIX_FMT_ARGB
-  #define AV_PIX_FMT_ABGR PIX_FMT_ABGR
-  #define AV_PIX_FMT_RGBA PIX_FMT_RGBA
-  #define AV_PIX_FMT_GRAY8 PIX_FMT_GRAY8
-  #define AV_PIX_FMT_YUYV422 PIX_FMT_YUYV422
-  #define AV_PIX_FMT_YUV422P PIX_FMT_YUV422P
-  #define AV_PIX_FMT_YUV411P PIX_FMT_YUV411P
-  #define AV_PIX_FMT_YUV444P PIX_FMT_YUV444P
-  #define AV_PIX_FMT_YUV410P PIX_FMT_YUV410P
-  #define AV_PIX_FMT_YUV420P PIX_FMT_YUV420P
-  #define AV_PIX_FMT_YUVJ444P PIX_FMT_YUVJ444P
-  #define AV_PIX_FMT_UYVY422 PIX_FMT_UYVY422
-  #define AV_PIX_FMT_YUVJ420P PIX_FMT_YUVJ420P
-  #define AV_PIX_FMT_YUVJ422P PIX_FMT_YUVJ422P
-  #define AV_PIX_FMT_UYVY422 PIX_FMT_UYVY422
-  #define AV_PIX_FMT_UYYVYY411 PIX_FMT_UYYVYY411
-  #define AV_PIX_FMT_BGR565 PIX_FMT_BGR565
-  #define AV_PIX_FMT_BGR555 PIX_FMT_BGR555
-  #define AV_PIX_FMT_BGR8 PIX_FMT_BGR8
-  #define AV_PIX_FMT_BGR4 PIX_FMT_BGR4
-  #define AV_PIX_FMT_BGR4_BYTE PIX_FMT_BGR4_BYTE
-  #define AV_PIX_FMT_RGB8 PIX_FMT_RGB8
-  #define AV_PIX_FMT_RGB4 PIX_FMT_RGB4
-  #define AV_PIX_FMT_RGB4_BYTE PIX_FMT_RGB4_BYTE
-  #define AV_PIX_FMT_NV12 PIX_FMT_NV12
-  #define AV_PIX_FMT_NV21 PIX_FMT_NV21
-  #define AV_PIX_FMT_RGB32_1 PIX_FMT_RGB32_1
-  #define AV_PIX_FMT_BGR32_1 PIX_FMT_BGR32_1
-  #define AV_PIX_FMT_GRAY16BE PIX_FMT_GRAY16BE
-  #define AV_PIX_FMT_GRAY16LE PIX_FMT_GRAY16LE
-  #define AV_PIX_FMT_YUV440P PIX_FMT_YUV440P
-  #define AV_PIX_FMT_YUVJ440P PIX_FMT_YUVJ440P
-  #define AV_PIX_FMT_YUVA420P PIX_FMT_YUVA420P
-  //#define AV_PIX_FMT_VDPAU_H264 PIX_FMT_VDPAU_H264
-  //#define AV_PIX_FMT_VDPAU_MPEG1 PIX_FMT_VDPAU_MPEG1
-  //#define AV_PIX_FMT_VDPAU_MPEG2 PIX_FMT_VDPAU_MPEG2
+    #define _AVPIXELFORMAT PixelFormat
+    #define AV_PIX_FMT_NONE PIX_FMT_NONE
+    #define AV_PIX_FMT_RGB444 PIX_FMT_RGB444
+    #define AV_PIX_FMT_RGB555 PIX_FMT_RGB555
+    #define AV_PIX_FMT_RGB565 PIX_FMT_RGB565
+    #define AV_PIX_FMT_BGR24 PIX_FMT_BGR24
+    #define AV_PIX_FMT_RGB24 PIX_FMT_RGB24
+    #define AV_PIX_FMT_BGRA PIX_FMT_BGRA
+    #define AV_PIX_FMT_ARGB PIX_FMT_ARGB
+    #define AV_PIX_FMT_ABGR PIX_FMT_ABGR
+    #define AV_PIX_FMT_RGBA PIX_FMT_RGBA
+    #define AV_PIX_FMT_GRAY8 PIX_FMT_GRAY8
+    #define AV_PIX_FMT_YUYV422 PIX_FMT_YUYV422
+    #define AV_PIX_FMT_YUV422P PIX_FMT_YUV422P
+    #define AV_PIX_FMT_YUV411P PIX_FMT_YUV411P
+    #define AV_PIX_FMT_YUV444P PIX_FMT_YUV444P
+    #define AV_PIX_FMT_YUV410P PIX_FMT_YUV410P
+    #define AV_PIX_FMT_YUV420P PIX_FMT_YUV420P
+    #define AV_PIX_FMT_YUVJ444P PIX_FMT_YUVJ444P
+    #define AV_PIX_FMT_UYVY422 PIX_FMT_UYVY422
+    #define AV_PIX_FMT_YUVJ420P PIX_FMT_YUVJ420P
+    #define AV_PIX_FMT_YUVJ422P PIX_FMT_YUVJ422P
+    #define AV_PIX_FMT_UYVY422 PIX_FMT_UYVY422
+    #define AV_PIX_FMT_UYYVYY411 PIX_FMT_UYYVYY411
+    #define AV_PIX_FMT_BGR565 PIX_FMT_BGR565
+    #define AV_PIX_FMT_BGR555 PIX_FMT_BGR555
+    #define AV_PIX_FMT_BGR8 PIX_FMT_BGR8
+    #define AV_PIX_FMT_BGR4 PIX_FMT_BGR4
+    #define AV_PIX_FMT_BGR4_BYTE PIX_FMT_BGR4_BYTE
+    #define AV_PIX_FMT_RGB8 PIX_FMT_RGB8
+    #define AV_PIX_FMT_RGB4 PIX_FMT_RGB4
+    #define AV_PIX_FMT_RGB4_BYTE PIX_FMT_RGB4_BYTE
+    #define AV_PIX_FMT_NV12 PIX_FMT_NV12
+    #define AV_PIX_FMT_NV21 PIX_FMT_NV21
+    #define AV_PIX_FMT_RGB32_1 PIX_FMT_RGB32_1
+    #define AV_PIX_FMT_BGR32_1 PIX_FMT_BGR32_1
+    #define AV_PIX_FMT_GRAY16BE PIX_FMT_GRAY16BE
+    #define AV_PIX_FMT_GRAY16LE PIX_FMT_GRAY16LE
+    #define AV_PIX_FMT_YUV440P PIX_FMT_YUV440P
+    #define AV_PIX_FMT_YUVJ440P PIX_FMT_YUVJ440P
+    #define AV_PIX_FMT_YUVA420P PIX_FMT_YUVA420P
+    //#define AV_PIX_FMT_VDPAU_H264 PIX_FMT_VDPAU_H264
+    //#define AV_PIX_FMT_VDPAU_MPEG1 PIX_FMT_VDPAU_MPEG1
+    //#define AV_PIX_FMT_VDPAU_MPEG2 PIX_FMT_VDPAU_MPEG2
 #endif
 #endif /* HAVE_LIBAVUTIL_AVUTIL_H */
 
@@ -121,8 +119,8 @@ extern "C" {
  * b and c the minor and micro versions of libav
  * d and e the minor and micro versions of FFmpeg */
 #define LIBAVCODEC_VERSION_CHECK(a, b, c, d, e) \
-  ( (LIBAVCODEC_VERSION_MICRO <  100 && LIBAVCODEC_VERSION_INT >= AV_VERSION_INT(a, b, c) ) || \
-    (LIBAVCODEC_VERSION_MICRO >= 100 && LIBAVCODEC_VERSION_INT >= AV_VERSION_INT(a, d, e) ) )
+    ( (LIBAVCODEC_VERSION_MICRO <  100 && LIBAVCODEC_VERSION_INT >= AV_VERSION_INT(a, b, c) ) || \
+      (LIBAVCODEC_VERSION_MICRO >= 100 && LIBAVCODEC_VERSION_INT >= AV_VERSION_INT(a, d, e) ) )
 
 #elif HAVE_FFMPEG_AVCODEC_H
 #include <ffmpeg/avcodec.h>
@@ -130,9 +128,9 @@ extern "C" {
 
 #if defined(HAVE_LIBAVCODEC_AVCODEC_H)
 #if LIBAVCODEC_VERSION_CHECK(54, 25, 0, 51, 100)
-  #define _AVCODECID AVCodecID
+    #define _AVCODECID AVCodecID
 #else
-  #define _AVCODECID CodecID
+    #define _AVCODECID CodecID
 #endif
 #endif /* HAVE_LIBAVCODEC_AVCODEC_H */
 
@@ -146,8 +144,8 @@ extern "C" {
  * b and c the minor and micro versions of libav
  * d and e the minor and micro versions of FFmpeg */
 #define LIBAVFORMAT_VERSION_CHECK(a, b, c, d, e) \
-  ( (LIBAVFORMAT_VERSION_MICRO <  100 && LIBAVFORMAT_VERSION_INT >= AV_VERSION_INT(a, b, c) ) || \
-    (LIBAVFORMAT_VERSION_MICRO >= 100 && LIBAVFORMAT_VERSION_INT >= AV_VERSION_INT(a, d, e) ) )
+    ( (LIBAVFORMAT_VERSION_MICRO <  100 && LIBAVFORMAT_VERSION_INT >= AV_VERSION_INT(a, b, c) ) || \
+      (LIBAVFORMAT_VERSION_MICRO >= 100 && LIBAVFORMAT_VERSION_INT >= AV_VERSION_INT(a, d, e) ) )
 
 #elif HAVE_FFMPEG_AVFORMAT_H
 #include <ffmpeg/avformat.h>
@@ -162,8 +160,8 @@ extern "C" {
  * b and c the minor and micro versions of libav
  * d and e the minor and micro versions of FFmpeg */
 #define LIBAVDEVICE_VERSION_CHECK(a, b, c, d, e) \
-  ( (LIBAVDEVICE_VERSION_MICRO <  100 && LIBAVDEVICE_VERSION_INT >= AV_VERSION_INT(a, b, c) ) || \
-    (LIBAVDEVICE_VERSION_MICRO >= 100 && LIBAVDEVICE_VERSION_INT >= AV_VERSION_INT(a, d, e) ) )
+    ( (LIBAVDEVICE_VERSION_MICRO <  100 && LIBAVDEVICE_VERSION_INT >= AV_VERSION_INT(a, b, c) ) || \
+      (LIBAVDEVICE_VERSION_MICRO >= 100 && LIBAVDEVICE_VERSION_INT >= AV_VERSION_INT(a, d, e) ) )
 
 #elif HAVE_FFMPEG_AVDEVICE_H
 #include <ffmpeg/avdevice.h>
@@ -178,8 +176,8 @@ extern "C" {
  * b and c the minor and micro versions of libav
  * d and e the minor and micro versions of FFmpeg */
 #define LIBSWSCALE_VERSION_CHECK(a, b, c, d, e) \
-  ( (LIBSWSCALE_VERSION_MICRO <  100 && LIBSWSCALE_VERSION_INT >= AV_VERSION_INT(a, b, c) ) || \
-    (LIBSWSCALE_VERSION_MICRO >= 100 && LIBSWSCALE_VERSION_INT >= AV_VERSION_INT(a, d, e) ) )
+    ( (LIBSWSCALE_VERSION_MICRO <  100 && LIBSWSCALE_VERSION_INT >= AV_VERSION_INT(a, b, c) ) || \
+      (LIBSWSCALE_VERSION_MICRO >= 100 && LIBSWSCALE_VERSION_INT >= AV_VERSION_INT(a, d, e) ) )
 
 #elif HAVE_FFMPEG_SWSCALE_H
 #include <ffmpeg/swscale.h>
@@ -199,35 +197,13 @@ extern "C" {
  #endif
 #endif
 
+/* A single function to initialize ffmpeg, to avoid multiple initializations */		
+void FFMPEGInit();
+
 #if HAVE_LIBAVUTIL
 enum _AVPIXELFORMAT GetFFMPEGPixelFormat(unsigned int p_colours, unsigned p_subpixelorder);
 #endif // HAVE_LIBAVUTIL
 
-
-/* SWScale wrapper class to make our life easier and reduce code reuse */
-#if HAVE_LIBSWSCALE && HAVE_LIBAVUTIL
-class SWScale {
-public:
-  SWScale();
-  ~SWScale();
-  int SetDefaults(enum _AVPIXELFORMAT in_pf, enum _AVPIXELFORMAT out_pf, unsigned int width, unsigned int height);
-  int ConvertDefaults(const Image* img, uint8_t* out_buffer, const size_t out_buffer_size);
-  int ConvertDefaults(const uint8_t* in_buffer, const size_t in_buffer_size, uint8_t* out_buffer, const size_t out_buffer_size);
-  int Convert(const Image* img, uint8_t* out_buffer, const size_t out_buffer_size, enum _AVPIXELFORMAT in_pf, enum _AVPIXELFORMAT out_pf, unsigned int width, unsigned int height);
-  int Convert(const uint8_t* in_buffer, const size_t in_buffer_size, uint8_t* out_buffer, const size_t out_buffer_size, enum _AVPIXELFORMAT in_pf, enum _AVPIXELFORMAT out_pf, unsigned int width, unsigned int height);
-
-protected:
-  bool gotdefaults;
-  struct SwsContext* swscale_ctx;
-  AVFrame* input_avframe;
-  AVFrame* output_avframe;
-  enum _AVPIXELFORMAT default_input_pf;
-  enum _AVPIXELFORMAT default_output_pf;
-  unsigned int default_width;
-  unsigned int default_height;
-};
-#endif // HAVE_LIBSWSCALE && HAVE_LIBAVUTIL
-
 #if !LIBAVCODEC_VERSION_CHECK(54, 25, 0, 51, 100)
 #define AV_CODEC_ID_NONE CODEC_ID_NONE
 #define AV_CODEC_ID_PCM_MULAW CODEC_ID_PCM_MULAW
@@ -261,19 +237,18 @@ protected:
  */
 #ifdef  __cplusplus
 
-  inline static const std::string av_make_error_string(int errnum)
-  {
-    char errbuf[AV_ERROR_MAX_STRING_SIZE];
+    inline static const std::string av_make_error_string(int errnum) {
+        static char errbuf[AV_ERROR_MAX_STRING_SIZE];
 #if LIBAVUTIL_VERSION_CHECK(50, 13, 0, 13, 0)
-    av_strerror(errnum, errbuf, AV_ERROR_MAX_STRING_SIZE);
+        av_strerror(errnum, errbuf, AV_ERROR_MAX_STRING_SIZE);
 #else
-    snprintf(errbuf, AV_ERROR_MAX_STRING_SIZE, "libav error %d", errnum);
+		snprintf(errbuf, AV_ERROR_MAX_STRING_SIZE, "libav error %d", errnum);
 #endif
-    return (std::string)errbuf;
-  }
+        return (std::string)errbuf;
+    }
 
-  #undef av_err2str
-  #define av_err2str(errnum) av_make_error_string(errnum).c_str()
+    #undef av_err2str
+    #define av_err2str(errnum) av_make_error_string(errnum).c_str()
 
   /* The following is copied directly from newer ffmpeg */
   #if LIBAVUTIL_VERSION_CHECK(52, 7, 0, 17, 100)
@@ -288,4 +263,69 @@ protected:
 
 #endif // ( HAVE_LIBAVUTIL_AVUTIL_H || HAVE_LIBAVCODEC_AVCODEC_H || HAVE_LIBAVFORMAT_AVFORMAT_H || HAVE_LIBAVDEVICE_AVDEVICE_H )
 
+#ifndef avformat_alloc_output_context2
+int hacked_up_context2_for_older_ffmpeg(AVFormatContext **avctx, AVOutputFormat *oformat, const char *format, const char *filename);
+#define avformat_alloc_output_context2(x,y,z,a) hacked_up_context2_for_older_ffmpeg(x,y,z,a)
+#endif
+
+#ifndef av_rescale_delta
+/**
+ * Rescale a timestamp while preserving known durations.
+ */
+int64_t av_rescale_delta(AVRational in_tb, int64_t in_ts,  AVRational fs_tb, int duration, int64_t *last, AVRational out_tb);
+#endif
+
+#ifndef av_clip64
+/**
+ * Clip a signed 64bit integer value into the amin-amax range.
+ * @param a value to clip
+ * @param amin minimum value of the clip range
+ * @param amax maximum value of the clip range
+ * @return clipped value
+ */
+static av_always_inline av_const int64_t av_clip64_c(int64_t a, int64_t amin, int64_t amax)
+{
+    if      (a < amin) return amin;
+    else if (a > amax) return amax;
+    else               return a;
+}
+
+#define av_clip64        av_clip64_c
+#endif
+
+void zm_dump_stream_format(AVFormatContext *ic, int i, int index, int is_output);
+void zm_dump_codec ( const AVCodecContext *codec );
+#if LIBAVCODEC_VERSION_CHECK(57, 64, 0, 64, 0)
+void zm_dump_codecpar ( const AVCodecParameters *par );
+#endif
+
+#if LIBAVCODEC_VERSION_CHECK(56, 8, 0, 60, 100)
+    #define zm_av_packet_unref( packet ) av_packet_unref( packet )
+    #define zm_av_packet_ref( dst, src ) av_packet_ref( dst, src )
+#else
+    unsigned int zm_av_packet_ref( AVPacket *dst, AVPacket *src );
+    #define zm_av_packet_unref( packet ) av_free_packet( packet )
+#endif
+#if LIBAVCODEC_VERSION_CHECK(52, 23, 0, 23, 0)
+      #define zm_avcodec_decode_video( context, rawFrame, frameComplete, packet ) avcodec_decode_video2( context, rawFrame, frameComplete, packet )
+#else
+      #define zm_avcodec_decode_video(context, rawFrame, frameComplete, packet ) avcodec_decode_video( context, rawFrame, frameComplete, packet->data, packet->size)
+#endif
+    
+#if LIBAVCODEC_VERSION_CHECK(55, 28, 1, 45, 101)
+  #define zm_av_frame_alloc() av_frame_alloc()
+#else
+  #define zm_av_frame_alloc() avcodec_alloc_frame()
+#endif
+
+#if ! LIBAVCODEC_VERSION_CHECK(55, 28, 1, 45, 101)
+  #define av_frame_free( input_avframe ) av_freep( input_avframe )
+#endif   
+
+int check_sample_fmt(AVCodec *codec, enum AVSampleFormat sample_fmt);
+
+bool is_video_stream( AVStream * stream );
+bool is_audio_stream( AVStream * stream );
+int zm_receive_frame( AVCodecContext *context, AVFrame *frame, AVPacket &packet );
+void dumpPacket(AVPacket *,const char *text="DEBUG");
 #endif // ZM_FFMPEG_H
