@@ -21,8 +21,7 @@
 #define ZM_IMAGE_H
 
 #include "zm.h"
-extern "C"
-{
+extern "C" {
 #include "zm_jpeg.h"
 }
 #include "zm_rgb.h"
@@ -32,6 +31,9 @@ extern "C"
 #include "zm_mem_utils.h"
 #include "zm_utils.h"
 
+class Image;
+#include "zm_ffmpeg.h"
+
 #include <errno.h>
 
 #if HAVE_ZLIB_H
@@ -54,24 +56,27 @@ extern imgbufcpy_fptr_t fptr_imgbufcpy;
 
 /* Should be called from Image class functions */
 inline static uint8_t* AllocBuffer(size_t p_bufsize) {
-	uint8_t* buffer = (uint8_t*)zm_mallocaligned(16,p_bufsize);
-	if(buffer == NULL)
+	uint8_t* buffer = (uint8_t*)zm_mallocaligned(64,p_bufsize);
+	if ( buffer == NULL )
 		Fatal("Memory allocation failed: %s",strerror(errno));
 	
 	return buffer;
 }
 
 inline static void DumpBuffer(uint8_t* buffer, int buffertype) {
-	if (buffer && buffertype != ZM_BUFTYPE_DONTFREE) {
-		if(buffertype == ZM_BUFTYPE_ZM)
-			zm_freealigned(buffer);
-		else if(buffertype == ZM_BUFTYPE_MALLOC)
-			free(buffer);
-		else if(buffertype == ZM_BUFTYPE_NEW)
-			delete buffer;
+	if ( buffer && buffertype != ZM_BUFTYPE_DONTFREE ) {
+    if ( buffertype == ZM_BUFTYPE_ZM ) {
+      zm_freealigned(buffer);
+    } else if ( buffertype == ZM_BUFTYPE_MALLOC ) {
+      free(buffer);
+    } else if ( buffertype == ZM_BUFTYPE_NEW ) {
+      delete buffer;
 		/*else if(buffertype == ZM_BUFTYPE_AVMALLOC)
 			av_free(buffer);
 		*/
+    } else {
+      Error( "Unknown buffer type in DumpBuffer(%d)", buffertype );
+    } 
 	}
 }
 
@@ -80,28 +85,24 @@ inline static void DumpBuffer(uint8_t* buffer, int buffertype) {
 // This is image class, and represents a frame captured from a 
 // camera in raw form.
 //
-class Image
-{
+class Image {
 protected:
 
-	struct Edge
-	{
+	struct Edge {
 		int min_y;
 		int max_y;
 		double min_x;
 		double _1_m;
 
-		static int CompareYX( const void *p1, const void *p2 )
-		{
-			const Edge *e1 = (const Edge *)p1, *e2 = (const Edge *)p2;
+		static int CompareYX( const void *p1, const void *p2 ) {
+			const Edge *e1 = reinterpret_cast<const Edge *>(p1), *e2 = reinterpret_cast<const Edge *>(p2);
 			if ( e1->min_y == e2->min_y )
 				return( int(e1->min_x - e2->min_x) );
 			else
 				return( int(e1->min_y - e2->min_y) );
 		}
-		static int CompareX( const void *p1, const void *p2 )
-		{
-			const Edge *e1 = (const Edge *)p1, *e2 = (const Edge *)p2;
+		static int CompareX( const void *p1, const void *p2 ) {
+			const Edge *e1 = reinterpret_cast<const Edge *>(p1), *e2 = reinterpret_cast<const Edge *>(p2);
 			return( int(e1->min_x - e2->min_x) );
 		}
 	};
@@ -113,7 +114,7 @@ protected:
 	}
 	
 	inline void AllocImgBuffer(size_t p_bufsize) {
-		if(buffer)
+		if ( buffer ) 
 			DumpImgBuffer();
 		
 		buffer = AllocBuffer(p_bufsize);
@@ -149,26 +150,26 @@ protected:
 	int holdbuffer; /* Hold the buffer instead of replacing it with new one */
 	char text[1024];
 
-
 public:
 	Image();
-	Image( const char *filename );
+	explicit Image( const char *filename );
 	Image( int p_width, int p_height, int p_colours, int p_subpixelorder, uint8_t *p_buffer=0);
-	Image( const Image &p_image );
+	explicit Image( const Image &p_image );
+  explicit Image( const AVFrame *frame );
 	~Image();
 	static void Initialise();
 	static void Deinitialise();
 
-	inline unsigned int Width() const { return( width ); }
-	inline unsigned int Height() const { return( height ); }
-	inline unsigned int Pixels() const { return( pixels ); }
-	inline unsigned int Colours() const { return( colours ); }
-	inline unsigned int SubpixelOrder() const { return( subpixelorder ); }
-	inline unsigned int Size() const { return( size ); }
+	inline unsigned int Width() const { return width; }
+	inline unsigned int Height() const { return height; }
+	inline unsigned int Pixels() const { return pixels; }
+	inline unsigned int Colours() const { return colours; }
+	inline unsigned int SubpixelOrder() const { return subpixelorder; }
+	inline unsigned int Size() const { return size; }
 	
 	/* Internal buffer should not be modified from functions outside of this class */
-	inline const uint8_t* Buffer() const { return( buffer ); }
-	inline const uint8_t* Buffer( unsigned int x, unsigned int y= 0 ) const { return( &buffer[colours*((y*width)+x)] ); }
+	inline const uint8_t* Buffer() const { return buffer; }
+	inline const uint8_t* Buffer( unsigned int x, unsigned int y= 0 ) const { return &buffer[colours*((y*width)+x)]; }
 	/* Request writeable buffer */
 	uint8_t* WriteBuffer(const unsigned int p_width, const unsigned int p_height, const unsigned int p_colours, const unsigned int p_subpixelorder);
 	
@@ -176,29 +177,26 @@ public:
 	inline void HoldBuffer(int tohold) { holdbuffer = tohold; }
 	
 	inline void Empty() {
-	if(!holdbuffer)
-		DumpImgBuffer();
-	
-	width = height = colours = size = pixels = subpixelorder = 0;
+    if ( !holdbuffer )
+      DumpImgBuffer();
+
+    width = height = colours = size = pixels = subpixelorder = 0;
 	}
 	
 	void Assign( unsigned int p_width, unsigned int p_height, unsigned int p_colours, unsigned int p_subpixelorder, const uint8_t* new_buffer, const size_t buffer_size);
 	void Assign( const Image &image );
 	void AssignDirect( const unsigned int p_width, const unsigned int p_height, const unsigned int p_colours, const unsigned int p_subpixelorder, uint8_t *new_buffer, const size_t buffer_size, const int p_buffertype);
 
-	inline void CopyBuffer( const Image &image )
-	{
+	inline void CopyBuffer( const Image &image ) {
 		Assign(image);
 	}
-	inline Image &operator=( const Image &image )
-	{
+	inline Image &operator=( const Image &image ) {
 		Assign(image);
 		return *this;
 	}
-	inline Image &operator=( const unsigned char *new_buffer )
-	{
+	inline Image &operator=( const unsigned char *new_buffer ) {
 		(*fptr_imgbufcpy)(buffer, new_buffer, size);
-		return( *this );
+		return *this;
 	}
 
 	bool ReadRaw( const char *filename );
@@ -207,9 +205,9 @@ public:
 	bool ReadJpeg( const char *filename, unsigned int p_colours, unsigned int p_subpixelorder);
 
 	bool WriteJpeg ( const char *filename) const;
-        bool WriteJpeg ( const char *filename, int quality_override ) const;
-        bool WriteJpeg ( const char *filename, struct timeval timestamp ) const;
-        bool WriteJpeg ( const char *filename, int quality_override, struct timeval timestamp ) const;
+  bool WriteJpeg ( const char *filename, int quality_override ) const;
+  bool WriteJpeg ( const char *filename, struct timeval timestamp ) const;
+  bool WriteJpeg ( const char *filename, int quality_override, struct timeval timestamp ) const;
 
 	bool DecodeJpeg( const JOCTET *inbuffer, int inbuffer_size, unsigned int p_colours, unsigned int p_subpixelorder);
 	bool EncodeJpeg( JOCTET *outbuffer, int *outbuffer_size, int quality_override=0 ) const;
@@ -232,7 +230,7 @@ public:
 	void Delta( const Image &image, Image* targetimage) const;
 
 	const Coord centreCoord( const char *text ) const;
-        void MaskPrivacy( const unsigned char *p_bitmask, const Rgb pixel_colour=0x00222222 );
+  void MaskPrivacy( const unsigned char *p_bitmask, const Rgb pixel_colour=0x00222222 );
 	void Annotate( const char *p_text, const Coord &coord, const unsigned int size=1, const Rgb fg_colour=RGB_WHITE, const Rgb bg_colour=RGB_BLACK );
 	Image *HighlightEdges( Rgb colour, unsigned int p_colours, unsigned int p_subpixelorder, const Box *limits=0 );
 	//Image *HighlightEdges( Rgb colour, const Polygon &polygon );
@@ -264,6 +262,8 @@ public:
 /* Blend functions */
 void sse2_fastblend(const uint8_t* col1, const uint8_t* col2, uint8_t* result, unsigned long count, double blendpercent);
 void std_fastblend(const uint8_t* col1, const uint8_t* col2, uint8_t* result, unsigned long count, double blendpercent);
+void neon32_armv7_fastblend(const uint8_t* col1, const uint8_t* col2, uint8_t* result, unsigned long count, double blendpercent);
+void neon64_armv8_fastblend(const uint8_t* col1, const uint8_t* col2, uint8_t* result, unsigned long count, double blendpercent);
 void std_blend(const uint8_t* col1, const uint8_t* col2, uint8_t* result, unsigned long count, double blendpercent);
 
 /* Delta functions */
@@ -274,6 +274,17 @@ void std_delta8_rgba(const uint8_t* col1, const uint8_t* col2, uint8_t* result,
 void std_delta8_bgra(const uint8_t* col1, const uint8_t* col2, uint8_t* result, unsigned long count);
 void std_delta8_argb(const uint8_t* col1, const uint8_t* col2, uint8_t* result, unsigned long count);
 void std_delta8_abgr(const uint8_t* col1, const uint8_t* col2, uint8_t* result, unsigned long count);
+
+void neon32_armv7_delta8_gray8(const uint8_t* col1, const uint8_t* col2, uint8_t* result, unsigned long count);
+void neon32_armv7_delta8_rgba(const uint8_t* col1, const uint8_t* col2, uint8_t* result, unsigned long count);
+void neon32_armv7_delta8_bgra(const uint8_t* col1, const uint8_t* col2, uint8_t* result, unsigned long count);
+void neon32_armv7_delta8_argb(const uint8_t* col1, const uint8_t* col2, uint8_t* result, unsigned long count);
+void neon32_armv7_delta8_abgr(const uint8_t* col1, const uint8_t* col2, uint8_t* result, unsigned long count);
+void neon64_armv8_delta8_gray8(const uint8_t* col1, const uint8_t* col2, uint8_t* result, unsigned long count);
+void neon64_armv8_delta8_rgba(const uint8_t* col1, const uint8_t* col2, uint8_t* result, unsigned long count);
+void neon64_armv8_delta8_bgra(const uint8_t* col1, const uint8_t* col2, uint8_t* result, unsigned long count);
+void neon64_armv8_delta8_argb(const uint8_t* col1, const uint8_t* col2, uint8_t* result, unsigned long count);
+void neon64_armv8_delta8_abgr(const uint8_t* col1, const uint8_t* col2, uint8_t* result, unsigned long count);
 void sse2_delta8_gray8(const uint8_t* col1, const uint8_t* col2, uint8_t* result, unsigned long count);
 void sse2_delta8_rgba(const uint8_t* col1, const uint8_t* col2, uint8_t* result, unsigned long count);
 void sse2_delta8_bgra(const uint8_t* col1, const uint8_t* col2, uint8_t* result, unsigned long count);
@@ -293,6 +304,9 @@ void std_convert_argb_gray8(const uint8_t* col1, uint8_t* result, unsigned long
 void std_convert_abgr_gray8(const uint8_t* col1, uint8_t* result, unsigned long count);
 void std_convert_yuyv_gray8(const uint8_t* col1, uint8_t* result, unsigned long count);
 void ssse3_convert_rgba_gray8(const uint8_t* col1, uint8_t* result, unsigned long count);
+void ssse3_convert_bgra_gray8(const uint8_t* col1, uint8_t* result, unsigned long count);
+void ssse3_convert_argb_gray8(const uint8_t* col1, uint8_t* result, unsigned long count);
+void ssse3_convert_abgr_gray8(const uint8_t* col1, uint8_t* result, unsigned long count);
 void ssse3_convert_yuyv_gray8(const uint8_t* col1, uint8_t* result, unsigned long count);
 void zm_convert_yuyv_rgb(const uint8_t* col1, uint8_t* result, unsigned long count);
 void zm_convert_yuyv_rgba(const uint8_t* col1, uint8_t* result, unsigned long count);
@@ -309,8 +323,3 @@ void std_deinterlace_4field_rgba(uint8_t* col1, uint8_t* col2, unsigned int thre
 void std_deinterlace_4field_bgra(uint8_t* col1, uint8_t* col2, unsigned int threshold, unsigned int width, unsigned int height);
 void std_deinterlace_4field_argb(uint8_t* col1, uint8_t* col2, unsigned int threshold, unsigned int width, unsigned int height);
 void std_deinterlace_4field_abgr(uint8_t* col1, uint8_t* col2, unsigned int threshold, unsigned int width, unsigned int height);
-void ssse3_deinterlace_4field_gray8(uint8_t* col1, uint8_t* col2, unsigned int threshold, unsigned int width, unsigned int height);
-void ssse3_deinterlace_4field_rgba(uint8_t* col1, uint8_t* col2, unsigned int threshold, unsigned int width, unsigned int height);
-void ssse3_deinterlace_4field_bgra(uint8_t* col1, uint8_t* col2, unsigned int threshold, unsigned int width, unsigned int height);
-void ssse3_deinterlace_4field_argb(uint8_t* col1, uint8_t* col2, unsigned int threshold, unsigned int width, unsigned int height);
-void ssse3_deinterlace_4field_abgr(uint8_t* col1, uint8_t* col2, unsigned int threshold, unsigned int width, unsigned int height);
