@@ -78,6 +78,8 @@ $SLANG = array(
     'Actual'               => 'Skutečná',
     'AddNewControl'        => 'Přidat nové řízení',
     'AddNewMonitor'        => 'Přidat kameru',
+    'AddNewServer'         => 'Add New Server',         // Added - 2018-08-30
+    'AddNewStorage'        => 'Add New Storage',        // Added - 2018-08-30
     'AddNewUser'           => 'Přidat uživatele',
     'AddNewZone'           => 'Přidat zónu',
     'Alarm'                => 'Alarm',
@@ -105,22 +107,32 @@ $SLANG = array(
     'AttrArchiveStatus'    => 'Archiv status',
     'AttrAvgScore'         => 'Prům. skóre',
     'AttrCause'            => 'Příčina',
-    'AttrDate'             => 'Datum',
-    'AttrDateTime'         => 'Datum/Čas',
     'AttrDiskBlocks'       => 'Bloky disku',
     'AttrDiskPercent'      => 'Zaplnění disku',
+    'AttrDiskSpace'        => 'Disk Space',             // Added - 2018-08-30
     'AttrDuration'         => 'Průběh',
+    'AttrEndDate'          => 'End Date',               // Added - 2018-08-30
+    'AttrEndDateTime'      => 'End Date/Time',          // Added - 2018-08-30
+    'AttrEndTime'          => 'End Time',               // Added - 2018-08-30
+    'AttrEndWeekday'       => 'End Weekday',            // Added - 2018-08-30
+    'AttrFilterServer'     => 'Server Filter is Running On', // Added - 2018-08-30
     'AttrFrames'           => 'Snímky',
     'AttrId'               => 'Id',
     'AttrMaxScore'         => 'Max. skóre',
     'AttrMonitorId'        => 'Kamera Id',
     'AttrMonitorName'      => 'Jméno kamery',
+    'AttrMonitorServer'    => 'Server Monitor is Running On', // Added - 2018-08-30
     'AttrName'             => 'Jméno',
     'AttrNotes'            => 'Notes',
+    'AttrStartDate'        => 'Start Date',             // Added - 2018-08-30
+    'AttrStartDateTime'    => 'Start Date/Time',        // Added - 2018-08-30
+    'AttrStartTime'        => 'Start Time',             // Added - 2018-08-30
+    'AttrStartWeekday'     => 'Start Weekday',          // Added - 2018-08-30
+    'AttrStateId'          => 'Run State',              // Added - 2018-08-30
+    'AttrStorageArea'      => 'Storage Area',           // Added - 2018-08-30
+    'AttrStorageServer'    => 'Server Hosting Storage', // Added - 2018-08-30
     'AttrSystemLoad'       => 'System Load',
-    'AttrTime'             => 'Čas',
     'AttrTotalScore'       => 'Celkové skóre',
-    'AttrWeekday'          => 'Den v týdnu',
     'Auto'                 => 'Auto',
     'AutoStopTimeout'      => 'Časový limit pro vypršení',
     'Available'            => 'Available',              // Added - 2009-03-31
@@ -153,9 +165,11 @@ $SLANG = array(
     'BadRefBlendPerc'      => 'Reference blend percentage must be a positive integer',
     'BadSectionLength'     => 'Section length must be an integer of 30 or more',
     'BadSignalCheckColour' => 'Signal check colour must be a valid RGB colour string',
+    'BadSourceType'        => 'Source Type \"Web Site\" requires the Function to be set to \"Monitor\"', // Added - 2018-08-30
     'BadStreamReplayBuffer'=> 'Stream replay buffer must be an integer of zero or more',
     'BadWarmupCount'       => 'Warmup frames must be an integer of zero or more',
     'BadWebColour'         => 'Web colour must be a valid web colour string',
+    'BadWebSitePath'       => 'Please enter a complete website url, including the http:// or https:// prefix.', // Added - 2018-08-30
     'BadWidth'             => 'Width must be set to a valid value',
     'Bandwidth'            => 'Rychlost sítě',
     'BandwidthHead'        => 'Bandwidth',	// This is the end of the bandwidth status on the top of the console, different in many language due to phrasing
@@ -219,10 +233,12 @@ $SLANG = array(
     'ChooseLogSelection'   => 'Choose a log selection', // Added - 2011-06-17
     'ChoosePreset'         => 'Choose Preset',
     'Clear'                => 'Clear',                  // Added - 2011-06-16
+    'CloneMonitor'         => 'Clone',                  // Added - 2018-08-30
     'Close'                => 'Zavřít',
     'Colour'               => 'Barva',
     'Command'              => 'Příkaz',
     'Component'            => 'Component',              // Added - 2011-06-16
+    'ConcurrentFilter'     => 'Run filter concurrently', // Added - 2018-08-30
     'Config'               => 'Nastavení',
     'ConfiguredFor'        => 'Nastaveno pro',
     'ConfirmDeleteEvents'  => 'Are you sure you wish to delete the selected events?',
@@ -280,9 +296,11 @@ $SLANG = array(
     'DonateRemindWeek'     => 'Nyní ne, připomenout za týden',
     'DonateYes'            => 'Ano, chcit podpořit ZoneMinder nyní',
     'Download'             => 'Stáhnout',
+    'DownloadVideo'        => 'Download Video',         // Added - 2018-08-30
     'DuplicateMonitorName' => 'Duplicate Monitor Name', // Added - 2009-03-31
     'Duration'             => 'Průběh',
     'Edit'                 => 'Editovat',
+    'EditLayout'           => 'Edit Layout',            // Added - 2018-08-30
     'Email'                => 'Email',
     'EnableAlarms'         => 'Povolit alarmy',
     'Enabled'              => 'Povoleno',
@@ -299,6 +317,7 @@ $SLANG = array(
     'Events'               => 'Záznamy',
     'Exclude'              => 'Vyjmout',
     'Execute'              => 'Execute',
+    'Exif'                 => 'Embed EXIF data into image', // Added - 2018-08-30
     'Export'               => 'Exportovat',
     'ExportDetails'        => 'Exportovat detaily záznamu',
     'ExportFailed'         => 'Chyba při exportu',
@@ -328,8 +347,10 @@ $SLANG = array(
     'FilterExecuteEvents'  => 'Spustit příkaz na všech nalezených',
     'FilterLog'            => 'Filter log',             // Added - 2015-04-18
     'FilterMessageEvents'  => 'Podat zprávu o všech nalezených',
+    'FilterMoveEvents'     => 'Move all matches',       // Added - 2018-08-30
     'FilterPx'             => 'Filtr Px',
     'FilterUnset'          => 'You must specify a filter width and height',
+    'FilterUpdateDiskSpace'=> 'Update used disk space', // Added - 2018-08-30
     'FilterUploadEvents'   => 'Uploadovat nalezené',
     'FilterVideoEvents'    => 'Create video for all matches',
     'Filters'              => 'Filtry',
@@ -354,6 +375,7 @@ $SLANG = array(
     'Function'             => 'Funkce',
     'Gain'                 => 'Zisk',
     'General'              => 'General',
+    'GenerateDownload'     => 'Generate Download',      // Added - 2018-08-30
     'GenerateVideo'        => 'Generovat video',
     'GeneratingVideo'      => 'Generuji video',
     'GoToZoneMinder'       => 'Jít na ZoneMinder.com',
@@ -374,6 +396,7 @@ $SLANG = array(
     'High'                 => 'Rychlá',
     'HighBW'               => 'Rychlá&nbsp;B/W',
     'Home'                 => 'Domů',
+    'Hostname'             => 'Hostname',               // Added - 2018-08-30
     'Hour'                 => 'Hodina',
     'Hue'                  => 'Odstín',
     'Id'                   => 'Id',
@@ -398,6 +421,7 @@ $SLANG = array(
     'Line'                 => 'Line',                   // Added - 2011-06-16
     'LinkedMonitors'       => 'Linked Monitors',
     'List'                 => 'Seznam',
+    'ListMatches'          => 'List Matches',           // Added - 2018-08-30
     'Load'                 => 'Load',
     'Local'                => 'Lokální',
     'Log'                  => 'Log',                    // Added - 2011-06-16
@@ -484,6 +508,7 @@ $SLANG = array(
     'MonitorProbeIntro'    => 'The list below shows detected analog and network cameras and whether they are already being used or available for selection.<br/><br/>Select the desired entry from the list below.<br/><br/>Please note that not all cameras may be detected and that choosing a camera here may overwrite any values you already have configured for the current monitor.<br/><br/>', // Added - 2009-03-31
     'Monitors'             => 'Kamery',
     'Montage'              => 'Sestřih',
+    'MontageReview'        => 'Montage Review',         // Added - 2018-08-30
     'Month'                => 'Měsíc',
     'More'                 => 'More',                   // Added - 2011-06-16
     'MotionFrameSkip'      => 'Motion Frame Skip',
@@ -510,6 +535,7 @@ $SLANG = array(
     'Next'                 => 'Další',
     'No'                   => 'Ne',
     'NoDetectedCameras'    => 'No Detected Cameras',    // Added - 2009-03-31
+    'NoDetectedProfiles'   => 'No Detected Profiles',   // Added - 2018-08-30
     'NoFramesRecorded'     => 'Pro tento snímek nejsou žádné záznamy',
     'NoGroup'              => 'No Group',
     'NoSavedFilters'       => 'Žádné uložené filtry',
@@ -528,6 +554,8 @@ $SLANG = array(
     'OpGt'                 => 'větší',
     'OpGtEq'               => 'větší nebo rovno',
     'OpIn'                 => 'nin set',
+    'OpIs'                 => 'is',                     // Added - 2018-08-30
+    'OpIsNot'              => 'is not',                 // Added - 2018-08-30
     'OpLt'                 => 'menší',
     'OpLtEq'               => 'menší nebo rovno',
     'OpMatches'            => 'obsahuje',
@@ -537,6 +565,7 @@ $SLANG = array(
     'Open'                 => 'Otevřít',
     'OptionHelp'           => 'MožnostHelp',
     'OptionRestartWarning' => 'Tyto změny se neprojeví\ndokud systém běží. Jakmile\ndokončíte provádění změn prosím\nrestartujte ZoneMinder.',
+    'OptionalEncoderParam' => 'Optional Encoder Parameters', // Added - 2018-08-30
     'Options'              => 'Možnosti',
     'OrEnterNewName'       => 'nebo vložte nové jméno',
     'Order'                => 'Pořadí',
@@ -574,9 +603,13 @@ $SLANG = array(
     'ProfileProbeIntro'    => 'The list below shows the existing stream profiles of the selected camera .<br/><br/>Select the desired entry from the list below.<br/><br/>Please note that ZoneMinder cannot configure additional profiles and that choosing a camera here may overwrite any values you already have configured for the current monitor.<br/><br/>', // Added - 2015-04-18
     'Progress'             => 'Progress',               // Added - 2015-04-18
     'Protocol'             => 'Protocol',
+    'RTSPDescribe'         => 'Use RTSP Response Media URL', // Added - 2018-08-30
+    'RTSPTransport'        => 'RTSP Transport Protocol', // Added - 2018-08-30
     'Rate'                 => 'Rychlost',
     'Real'                 => 'Skutečná',
+    'RecaptchaWarning'     => 'Your reCaptcha secret key is invalid. Please correct it, or reCaptcha will not work', // Added - 2018-08-30
     'Record'               => 'Nahrávat',
+    'RecordAudio'          => 'Whether to store the audio stream when saving an event.', // Added - 2018-08-30
     'RefImageBlendPct'     => 'Reference Image Blend %ge',
     'Refresh'              => 'Obnovit',
     'Remote'               => 'Síťová',
@@ -592,6 +625,7 @@ $SLANG = array(
     'ReplayAll'            => 'All Events',
     'ReplayGapless'        => 'Gapless Events',
     'ReplaySingle'         => 'Single Event',
+    'ReportEventAudit'     => 'Audit Events Report',    // Added - 2018-08-30
     'Reset'                => 'Reset',
     'ResetEventCounts'     => 'Resetovat počty záznamů',
     'Restart'              => 'Restartovat',
@@ -610,6 +644,7 @@ $SLANG = array(
     'Save'                 => 'Uložit',
     'SaveAs'               => 'Uložit jako',
     'SaveFilter'           => 'Uložit filtr',
+    'SaveJPEGs'            => 'Save JPEGs',             // Added - 2018-08-30
     'Scale'                => 'Velikost',
     'Score'                => 'Skóre',
     'Secs'                 => 'Délka(s)',
@@ -626,6 +661,7 @@ $SLANG = array(
     'ShowFilterWindow'     => 'Zobrazit filtr',
     'ShowTimeline'         => 'Zobrazit časovou linii ',
     'SignalCheckColour'    => 'Signal Check Colour',
+    'SignalCheckPoints'    => 'Signal Check Points',    // Added - 2018-08-30
     'Size'                 => 'Velikost',
     'SkinDescription'      => 'Change the default skin for this computer', // Added - 2011-01-30
     'Sleep'                => 'Spát',
@@ -645,6 +681,10 @@ $SLANG = array(
     'State'                => 'Stav',
     'Stats'                => 'Statistiky',
     'Status'               => 'Status',
+    'StatusConnected'      => 'Capturing',              // Added - 2018-08-30
+    'StatusNotRunning'     => 'Not Running',            // Added - 2018-08-30
+    'StatusRunning'        => 'Not Capturing',          // Added - 2018-08-30
+    'StatusUnknown'        => 'Unknown',                // Added - 2018-08-30
     'Step'                 => 'Krok',
     'StepBack'             => 'Step Back',
     'StepForward'          => 'Step Forward',
@@ -655,6 +695,8 @@ $SLANG = array(
     'Stills'               => 'Snímky',
     'Stop'                 => 'Zastavit',
     'Stopped'              => 'Zastaven',
+    'StorageArea'          => 'Storage Area',           // Added - 2018-08-30
+    'StorageScheme'        => 'Scheme',                 // Added - 2018-08-30
     'Stream'               => 'Stream',
     'StreamReplayBuffer'   => 'Stream Replay Image Buffer',
     'Submit'               => 'Potvrdit',
@@ -674,6 +716,7 @@ $SLANG = array(
     'TimelineTip4'          => 'Use the controls below to zoom out or navigate back and forward through the time range.',              // Added 2013.08.15.
     'Timestamp'            => 'Razítko',
     'TimestampLabelFormat' => 'Formát časového razítka',
+    'TimestampLabelSize'   => 'Font Size',              // Added - 2018-08-30
     'TimestampLabelX'      => 'Časové razítko X',
     'TimestampLabelY'      => 'Časové razítko Y',
     'Today'                => 'Dnes',
@@ -720,6 +763,7 @@ $SLANG = array(
     'VideoGenParms'        => 'Parametry generování videa',
     'VideoGenSucceeded'    => 'Video vygenerováno úspěšně!',
     'VideoSize'            => 'Velikost videa',
+    'VideoWriter'          => 'Video Writer',           // Added - 2018-08-30
     'View'                 => 'Zobrazit',
     'ViewAll'              => 'Zobrazit všechny',
     'ViewEvent'            => 'Zobrazit záznam',
@@ -729,6 +773,7 @@ $SLANG = array(
     'Watch'                => 'Sledovat',
     'Web'                  => 'Web',
     'WebColour'            => 'Webová barva',
+    'WebSiteUrl'           => 'Website URL',            // Added - 2018-08-30
     'Week'                 => 'Týden',
     'White'                => 'Bílá',
     'WhiteBalance'         => 'Vyvážení bílé',
