@@ -80,6 +80,8 @@ $SLANG = array(
     'Actual'               => 'Original',
     'AddNewControl'        => 'Neues Steuerelement hinzufügen',
     'AddNewMonitor'        => 'Neuer Monitor',
+    'AddNewServer'         => 'Add New Server',         // Added - 2018-08-30
+    'AddNewStorage'        => 'Add New Storage',        // Added - 2018-08-30
     'AddNewUser'           => 'Neuer Benutzer',
     'AddNewZone'           => 'Neue Zone',
     'Alarm'                => 'Alarm',
@@ -107,22 +109,32 @@ $SLANG = array(
     'AttrArchiveStatus'    => 'Archivstatus',
     'AttrAvgScore'         => 'Mittlere Wertung',
     'AttrCause'            => 'Grund',
-    'AttrDate'             => 'Datum',
-    'AttrDateTime'         => 'Datum/Zeit',
     'AttrDiskBlocks'       => 'Disk-Blöcke',
     'AttrDiskPercent'      => 'Disk-Prozent',
+    'AttrDiskSpace'        => 'Disk Space',             // Added - 2018-08-30
     'AttrDuration'         => 'Dauer',
+    'AttrEndDate'          => 'End Date',               // Added - 2018-08-30
+    'AttrEndDateTime'      => 'End Date/Time',          // Added - 2018-08-30
+    'AttrEndTime'          => 'End Time',               // Added - 2018-08-30
+    'AttrEndWeekday'       => 'End Weekday',            // Added - 2018-08-30
+    'AttrFilterServer'     => 'Server Filter is Running On', // Added - 2018-08-30
     'AttrFrames'           => 'Bilder',
     'AttrId'               => 'ID',
     'AttrMaxScore'         => 'Maximale Wertung',
     'AttrMonitorId'        => 'Monitor-ID',
     'AttrMonitorName'      => 'Monitorname',
+    'AttrMonitorServer'    => 'Server Monitor is Running On', // Added - 2018-08-30
     'AttrName'             => 'Name',
     'AttrNotes'            => 'Bemerkungen',
+    'AttrStartDate'        => 'Start Date',             // Added - 2018-08-30
+    'AttrStartDateTime'    => 'Start Date/Time',        // Added - 2018-08-30
+    'AttrStartTime'        => 'Start Time',             // Added - 2018-08-30
+    'AttrStartWeekday'     => 'Start Weekday',          // Added - 2018-08-30
+    'AttrStateId'          => 'Run State',              // Added - 2018-08-30
+    'AttrStorageArea'      => 'Storage Area',           // Added - 2018-08-30
+    'AttrStorageServer'    => 'Server Hosting Storage', // Added - 2018-08-30
     'AttrSystemLoad'       => 'Systemlast',
-    'AttrTime'             => 'Zeit',
     'AttrTotalScore'       => 'Gesamtwertung',
-    'AttrWeekday'          => 'Wochentag',
     'Auto'                 => 'Auto',
     'AutoStopTimeout'      => 'Auto-Stopp-Zeitüberschreitung',
     'Available'            => 'Verfügbar',              // Added - 2009-03-31
@@ -155,9 +167,11 @@ $SLANG = array(
     'BadRefBlendPerc'      => 'Der Referenz-Blenden-Prozentwert muss ganzzahlig 0 oder größer sein',
     'BadSectionLength'     => 'Die Bereichslänge muss ganzzahlig 0 oder größer sein',
     'BadSignalCheckColour' => 'Die Signalprüffarbe muss auf einen gültigen Farbwert eingestellt sein',
+    'BadSourceType'        => 'Source Type \"Web Site\" requires the Function to be set to \"Monitor\"', // Added - 2018-08-30
     'BadStreamReplayBuffer'=> 'Der Wiedergabestrompuffer muss eine ganze Zahl von null oder mehr betragen',
     'BadWarmupCount'       => 'Die Anzahl der Vorwärmbilder muss ganzzahlig 0 oder größer sein',
     'BadWebColour'         => 'Die Webfarbe muss auf einen gültigen Farbwert eingestellt sein',
+    'BadWebSitePath'       => 'Please enter a complete website url, including the http:// or https:// prefix.', // Added - 2018-08-30
     'BadWidth'             => 'Die Breite muss auf einen gültigen Wert eingestellt sein',
     'Bandwidth'            => 'Bandbreite',
     'BandwidthHead'        => 'Bandbreite',	// This is the end of the bandwidth status on the top of the console, different in many language due to phrasing
@@ -221,10 +235,12 @@ $SLANG = array(
     'ChooseLogSelection'   => 'Log-Auswahl', // Added - 2011-06-17
     'ChoosePreset'         => 'Voreinstellung auswählen',
     'Clear'                => 'Leeren',                  // Added - 2011-06-16
+    'CloneMonitor'         => 'Clone',                  // Added - 2018-08-30
     'Close'                => 'Schließen',
     'Colour'               => 'Farbe',
     'Command'              => 'Kommando',
     'Component'            => 'Komponente',              // Added - 2011-06-16
+    'ConcurrentFilter'     => 'Run filter concurrently', // Added - 2018-08-30
     'Config'               => 'Konfig.',
     'ConfiguredFor'        => 'Konfiguriert für',
     'ConfirmDeleteEvents'  => 'Sind Sie sicher, dass Sie die ausgewählten Ereignisse löschen wollen?',
@@ -282,9 +298,11 @@ $SLANG = array(
     'DonateRemindWeek'     => 'Noch nicht, erinnere mich in einer Woche noch mal.',
     'DonateYes'            => 'Ja, ich möchte jetzt spenden.',
     'Download'             => 'Download',
+    'DownloadVideo'        => 'Download Video',         // Added - 2018-08-30
     'DuplicateMonitorName' => 'Monitornamen Duplizieren', // Added - 2009-03-31
     'Duration'             => 'Dauer',
     'Edit'                 => 'Bearbeiten',
+    'EditLayout'           => 'Edit Layout',            // Added - 2018-08-30
     'Email'                => 'E-Mail',
     'EnableAlarms'         => 'Alarme aktivieren',
     'Enabled'              => 'Aktiviert',
@@ -301,6 +319,7 @@ $SLANG = array(
     'Events'               => 'Ereignisse',
     'Exclude'              => 'Ausschluss;',
     'Execute'              => 'Ausführen',
+    'Exif'                 => 'Embed EXIF data into image', // Added - 2018-08-30
     'Export'               => 'Exportieren',
     'ExportDetails'        => 'Exportiere Ereignis-Details',
     'ExportFailed'         => 'Exportieren fehlgeschlagen',
@@ -330,8 +349,10 @@ $SLANG = array(
     'FilterExecuteEvents'  => 'Ausführen bei allen Treffern',
     'FilterLog'            => 'Log filtern',             // Added - 2015-04-18
     'FilterMessageEvents'  => 'Detaillierte Nachricht zu allen Treffern',
+    'FilterMoveEvents'     => 'Move all matches',       // Added - 2018-08-30
     'FilterPx'             => 'Filter-Pixel',
     'FilterUnset'          => 'Sie müssen eine Breite und Höhe für das Filter angeben',
+    'FilterUpdateDiskSpace'=> 'Update used disk space', // Added - 2018-08-30
     'FilterUploadEvents'   => 'Hochladen aller Treffer',
     'FilterVideoEvents'    => 'Video für alle Treffer erstellen',
     'Filters'              => 'Filter',
@@ -356,6 +377,7 @@ $SLANG = array(
     'Function'             => 'Funktion',
     'Gain'                 => 'Verstärkung',
     'General'              => 'Allgemeines',
+    'GenerateDownload'     => 'Generate Download',      // Added - 2018-08-30
     'GenerateVideo'        => 'Erzeuge Video',
     'GeneratingVideo'      => 'Erzeuge Video...',
     'GoToZoneMinder'       => 'Besuche ZoneMinder.com',
@@ -376,6 +398,7 @@ $SLANG = array(
     'High'                 => 'hohe',
     'HighBW'               => 'Hohe B/W',
     'Home'                 => 'Home',
+    'Hostname'             => 'Hostname',               // Added - 2018-08-30
     'Hour'                 => 'Stunde',
     'Hue'                  => 'Farbton',
     'Id'                   => 'ID',
@@ -400,6 +423,7 @@ $SLANG = array(
     'Line'                 => 'Zeile',                   // Added - 2011-06-16
     'LinkedMonitors'       => 'Verbundene Monitore',
     'List'                 => 'Liste',
+    'ListMatches'          => 'List Matches',           // Added - 2018-08-30
     'Load'                 => 'Last',
     'Local'                => 'Lokal',
     'Log'                  => 'Log',                    // Added - 2011-06-16
@@ -486,6 +510,7 @@ $SLANG = array(
     'MonitorProbeIntro'    => 'Die nachfolgende Liste zeigt erkannte Analog- und Netzwerkkameras, ob sie bereits genutzt werden und ob sie zur Auswahl verfügbar sind.<br/><br/>Wähle den gewünschten Eintrag aus der folgenden Liste.<br/><br/>Bitte Beachten: Nicht alle  Kameras können erkannt werden. Die Auswahl einer Kamera kann bereits eingetragene Werte im aktuellen Monitor überschreiben.<br/><br/>', // Added - 2009-03-31
     'Monitors'             => 'Monitore',
     'Montage'              => 'Montage',
+    'MontageReview'        => 'Montage Review',         // Added - 2018-08-30
     'Month'                => 'Monat',
     'More'                 => 'Mehr',                   // Added - 2011-06-16
     'MotionFrameSkip'      => 'Motion Frame Skip',
@@ -512,6 +537,7 @@ $SLANG = array(
     'Next'                 => 'Nächstes',
     'No'                   => 'Nein',
     'NoDetectedCameras'    => 'Keine Kameras erkannt',    // Added - 2009-03-31
+    'NoDetectedProfiles'   => 'No Detected Profiles',   // Added - 2018-08-30
     'NoFramesRecorded'     => 'Es gibt keine Aufnahmen von diesem Ereignis.',
     'NoGroup'              => 'Keine Gruppe',
     'NoSavedFilters'       => 'Keine gespeicherten Filter',
@@ -530,6 +556,8 @@ $SLANG = array(
     'OpGt'                 => 'groesser als',
     'OpGtEq'               => 'groesser oder gleich wie',
     'OpIn'                 => 'in Satz',
+    'OpIs'                 => 'is',                     // Added - 2018-08-30
+    'OpIsNot'              => 'is not',                 // Added - 2018-08-30
     'OpLt'                 => 'kleiner als',
     'OpLtEq'               => 'kleiner oder gleich wie',
     'OpMatches'            => 'zutreffend',
@@ -539,6 +567,7 @@ $SLANG = array(
     'Open'                 => 'öffnen',
     'OptionHelp'           => 'Hilfe',
     'OptionRestartWarning' => 'Veränderungen werden erst nach einem Neustart des Programms aktiv.\nFür eine sofortige änderung starten Sie das Programm bitte neu.',
+    'OptionalEncoderParam' => 'Optional Encoder Parameters', // Added - 2018-08-30
     'Options'              => 'Optionen',
     'OrEnterNewName'       => 'oder neuen Namen eingeben',
     'Order'                => 'Reihenfolge',
@@ -576,9 +605,13 @@ $SLANG = array(
     'ProfileProbeIntro'    => 'Die folgende Liste zeigt die verfügbaren Streamingprofile der ausgewählten Kamera.<br/><br/>Wähle den gewünschten Eintrag aus der folgenden Liste.<br/><br/>Bitte Beachten: Zoneminder kann keine zusätzlichen Profile konfigurieren. Die Auswahl einer Kamera kann bereits eingetragene Werte im aktuellen Monitor überschreiben.<br/><br/>', // Added - 2015-04-18
     'Progress'             => 'Fortschritt',               // Added - 2015-04-18
     'Protocol'             => 'Protokoll',
+    'RTSPDescribe'         => 'Use RTSP Response Media URL', // Added - 2018-08-30
+    'RTSPTransport'        => 'RTSP Transport Protocol', // Added - 2018-08-30
     'Rate'                 => 'Abspielgeschwindigkeit',
     'Real'                 => 'Real',
+    'RecaptchaWarning'     => 'Your reCaptcha secret key is invalid. Please correct it, or reCaptcha will not work', // Added - 2018-08-30
     'Record'               => 'Aufnahme',
+    'RecordAudio'          => 'Whether to store the audio stream when saving an event.', // Added - 2018-08-30
     'RefImageBlendPct'     => 'Referenz-Bildblende',
     'Refresh'              => 'Aktualisieren',
     'Remote'               => 'Remote',
@@ -594,6 +627,7 @@ $SLANG = array(
     'ReplayAll'            => 'Alle Ereignisse',
     'ReplayGapless'        => 'Lückenlose Ereignisse',
     'ReplaySingle'         => 'Einzelereignis',
+    'ReportEventAudit'     => 'Audit Events Report',    // Added - 2018-08-30
     'Reset'                => 'Zurücksetzen',
     'ResetEventCounts'     => 'Lösche Ereignispunktzahl',
     'Restart'              => 'Neustart',
@@ -612,6 +646,7 @@ $SLANG = array(
     'Save'                 => 'Speichern',
     'SaveAs'               => 'Speichere als',
     'SaveFilter'           => 'Speichere Filter',
+    'SaveJPEGs'            => 'Save JPEGs',             // Added - 2018-08-30
     'Scale'                => 'Skalierung',
     'Score'                => 'Wertung',
     'Secs'                 => 'Sekunden',
@@ -628,6 +663,7 @@ $SLANG = array(
     'ShowFilterWindow'     => 'Zeige Filterfenster',
     'ShowTimeline'         => 'Zeige Zeitstrahl',
     'SignalCheckColour'    => 'Farbe des Signalchecks',
+    'SignalCheckPoints'    => 'Signal Check Points',    // Added - 2018-08-30
     'Size'                 => 'Größe',
     'SkinDescription'      => 'Wähle den standard Skin für diesen Computer.', // Added - 2011-01-30
     'Sleep'                => 'Schlaf',
@@ -647,6 +683,10 @@ $SLANG = array(
     'State'                => 'Status',
     'Stats'                => 'Statistik',
     'Status'               => 'Status',
+    'StatusConnected'      => 'Capturing',              // Added - 2018-08-30
+    'StatusNotRunning'     => 'Not Running',            // Added - 2018-08-30
+    'StatusRunning'        => 'Not Capturing',          // Added - 2018-08-30
+    'StatusUnknown'        => 'Unknown',                // Added - 2018-08-30
     'Step'                 => 'Stufe',
     'StepBack'             => 'Einen Schritt rückwärts',
     'StepForward'          => 'Einen Schritt vorwärts',
@@ -657,6 +697,8 @@ $SLANG = array(
     'Stills'               => 'Standbilder',
     'Stop'                 => 'Stop',
     'Stopped'              => 'Gestoppt',
+    'StorageArea'          => 'Storage Area',           // Added - 2018-08-30
+    'StorageScheme'        => 'Scheme',                 // Added - 2018-08-30
     'Stream'               => 'Stream',
     'StreamReplayBuffer'   => 'Stream-Wiedergabe-Bildpuffer',
     'Submit'               => 'Absenden',
@@ -676,9 +718,9 @@ $SLANG = array(
     'TimelineTip4'         => 'Verwenden Sie die Steuerelemente unten, um zu Zoomen oder navigieren Sie vorwärts und rückwärts durch die Zeit.',              // Added 2013.08.15.
     'Timestamp'            => 'Zeitstempel',
     'TimestampLabelFormat' => 'Format des Zeitstempels',
+    'TimestampLabelSize'   => 'Schriftgröße',
     'TimestampLabelX'      => 'Zeitstempel-X',
     'TimestampLabelY'      => 'Zeitstempel-Y',
-    'TimestampLabelSize'   => 'Schriftgröße',
     'Today'                => 'Heute',
     'Tools'                => 'Werkzeuge',
     'Total'                => 'Insgesamt',                 // Added - 2011-06-16
@@ -723,6 +765,7 @@ $SLANG = array(
     'VideoGenParms'        => 'Parameter der Videoerzeugung',
     'VideoGenSucceeded'    => 'Videoerzeugung erfolgreich!',
     'VideoSize'            => 'Videogröße',
+    'VideoWriter'          => 'Video Writer',           // Added - 2018-08-30
     'View'                 => 'Ansicht',
     'ViewAll'              => 'Alles ansehen',
     'ViewEvent'            => 'Zeige Ereignis',
@@ -732,6 +775,7 @@ $SLANG = array(
     'Watch'                => 'Beobachte',
     'Web'                  => 'Web',
     'WebColour'            => 'Webfarbe',
+    'WebSiteUrl'           => 'Website URL',            // Added - 2018-08-30
     'Week'                 => 'Woche',
     'White'                => 'Weiß',
     'WhiteBalance'         => 'Weiß-Abgleich',
