@@ -85,6 +85,8 @@ $SLANG = array(
     'Actual'                => 'Aktuaalne',
     'AddNewControl'         => 'Lisa uus Kontroll',
     'AddNewMonitor'         => 'Lisa uus Monitor',
+    'AddNewServer'         => 'Add New Server',         // Added - 2018-08-30
+    'AddNewStorage'        => 'Add New Storage',        // Added - 2018-08-30
     'AddNewUser'            => 'Lisa uus Kasutaja',
     'AddNewZone'            => 'Lisa uus Tsoon',
     'Alarm'                 => 'Alarm',
@@ -112,22 +114,32 @@ $SLANG = array(
     'AttrArchiveStatus'     => 'Arhiivi Staatus',
     'AttrAvgScore'          => 'Keskm. Skoor',
     'AttrCause'             => 'Põhjus',
-    'AttrDate'              => 'Kp.',
-    'AttrDateTime'          => 'Kp/Kellaaeg',
     'AttrDiskBlocks'        => 'Ketta Blokk',
     'AttrDiskPercent'       => 'Ketta Protsent',
+    'AttrDiskSpace'        => 'Disk Space',             // Added - 2018-08-30
     'AttrDuration'          => 'Kestvus',
+    'AttrEndDate'          => 'End Date',               // Added - 2018-08-30
+    'AttrEndDateTime'      => 'End Date/Time',          // Added - 2018-08-30
+    'AttrEndTime'          => 'End Time',               // Added - 2018-08-30
+    'AttrEndWeekday'       => 'End Weekday',            // Added - 2018-08-30
+    'AttrFilterServer'     => 'Server Filter is Running On', // Added - 2018-08-30
     'AttrFrames'            => 'Kaadrid',
     'AttrId'                => 'Id',
     'AttrMaxScore'          => 'Maks. Skoor',
     'AttrMonitorId'         => 'Monitori Id',
     'AttrMonitorName'       => 'Monitori Nimi',
+    'AttrMonitorServer'    => 'Server Monitor is Running On', // Added - 2018-08-30
     'AttrName'              => 'Nimi',
     'AttrNotes'             => 'Märkmed',
+    'AttrStartDate'        => 'Start Date',             // Added - 2018-08-30
+    'AttrStartDateTime'    => 'Start Date/Time',        // Added - 2018-08-30
+    'AttrStartTime'        => 'Start Time',             // Added - 2018-08-30
+    'AttrStartWeekday'     => 'Start Weekday',          // Added - 2018-08-30
+    'AttrStateId'          => 'Run State',              // Added - 2018-08-30
+    'AttrStorageArea'      => 'Storage Area',           // Added - 2018-08-30
+    'AttrStorageServer'    => 'Server Hosting Storage', // Added - 2018-08-30
     'AttrSystemLoad'        => 'Süsteemi Koormus',
-    'AttrTime'              => 'Kellaaeg',
     'AttrTotalScore'        => 'Skoor Kokku',
-    'AttrWeekday'           => 'Tööpäevad',
     'Auto'                  => 'Auto',
     'AutoStopTimeout'       => 'Auto Stop Ajalimiit',
     'Available'             => 'Saadaval',
@@ -160,9 +172,11 @@ $SLANG = array(
     'BadRefBlendPerc'       => 'Reference blend percentage must be a positive integer',
     'BadSectionLength'      => 'Section length must be an integer of 30 or more',
     'BadSignalCheckColour'  => 'Signal check colour must be a valid RGB colour string',
+    'BadSourceType'        => 'Source Type \"Web Site\" requires the Function to be set to \"Monitor\"', // Added - 2018-08-30
     'BadStreamReplayBuffer' => 'Stream replay buffer must be an integer of zero or more',
     'BadWarmupCount'        => 'Warmup frames must be an integer of zero or more',
     'BadWebColour'          => 'Web colour must be a valid web colour string',
+    'BadWebSitePath'       => 'Please enter a complete website url, including the http:// or https:// prefix.', // Added - 2018-08-30
     'BadWidth'              => 'Width must be set to a valid value',
     'Bandwidth'             => 'Ribalaius',
     'BandwidthHead'         => 'Ribalaius',	// This is the end of the bandwidth status on the top of the console, different in many language due to phrasing
@@ -226,10 +240,12 @@ $SLANG = array(
     'ChooseLogSelection'    => 'Choose a log selection', // Added - 2011-06-17
     'ChoosePreset'          => 'Choose Preset',
     'Clear'                 => 'Clear',                  // Added - 2011-06-16
+    'CloneMonitor'         => 'Clone',                  // Added - 2018-08-30
     'Close'                 => 'Sule',
     'Colour'                => 'Värv',
     'Command'               => 'Käsk',
     'Component'             => 'Komponent',              // Added - 2011-06-16
+    'ConcurrentFilter'     => 'Run filter concurrently', // Added - 2018-08-30
     'Config'                => 'Seadistus',
     'ConfiguredFor'         => 'Seadistatud',
     'ConfirmDeleteEvents'   => 'Oled sa kindel kustamaks valitud sündmused?',
@@ -287,9 +303,11 @@ $SLANG = array(
     'DonateRemindWeek'      => 'EI veel, tuleta meelde nädala pärast',
     'DonateYes'             => 'Jah, Ma soovin annetada',
     'Download'              => 'Lae alla',
+    'DownloadVideo'        => 'Download Video',         // Added - 2018-08-30
     'DuplicateMonitorName'  => 'Dubleeri Monitori Nimi',
     'Duration'              => 'Kestvus',
     'Edit'                  => 'Muuda',
+    'EditLayout'           => 'Edit Layout',            // Added - 2018-08-30
     'Email'                 => 'Email',
     'EnableAlarms'          => 'Luba Alarmid',
     'Enabled'               => 'Lubatud',
@@ -306,6 +324,7 @@ $SLANG = array(
     'Events'                => 'Sündmuseid',
     'Exclude'               => 'Jäta välja',
     'Execute'               => 'Käivita',
+    'Exif'                 => 'Embed EXIF data into image', // Added - 2018-08-30
     'Export'                => 'Eksport',
     'ExportDetails'         => 'Ekspordi Sündmuste Detailid',
     'ExportFailed'          => 'Eksportimine Ebaõnnestus',
@@ -335,8 +354,10 @@ $SLANG = array(
     'FilterExecuteEvents'   => 'Execute command on all matches',
     'FilterLog'            => 'Filter log',             // Added - 2015-04-18
     'FilterMessageEvents'   => 'Message details of all matches',
+    'FilterMoveEvents'     => 'Move all matches',       // Added - 2018-08-30
     'FilterPx'              => 'Filter Px',
     'FilterUnset'           => 'You must specify a filter width and height',
+    'FilterUpdateDiskSpace'=> 'Update used disk space', // Added - 2018-08-30
     'FilterUploadEvents'    => 'Upload all matches',
     'FilterVideoEvents'     => 'Create video for all matches',
     'Filters'               => 'Filtrid',
@@ -361,6 +382,7 @@ $SLANG = array(
     'Function'              => 'Funktsioon',
     'Gain'                  => 'Gain',
     'General'               => 'Peamine',
+    'GenerateDownload'     => 'Generate Download',      // Added - 2018-08-30
     'GenerateVideo'         => 'Genereeri Video',
     'GeneratingVideo'       => 'Genereerin Videot',
     'GoToZoneMinder'        => 'Mine ZoneMinder.com',
@@ -381,6 +403,7 @@ $SLANG = array(
     'High'                  => 'Suurim',
     'HighBW'                => 'High&nbsp;B/W',
     'Home'                  => 'Koju',
+    'Hostname'             => 'Hostname',               // Added - 2018-08-30
     'Hour'                  => 'Tunnis',
     'Hue'                   => 'Hue',
     'Id'                    => 'Id',
@@ -405,6 +428,7 @@ $SLANG = array(
     'Line'                  => 'Line',                   // Added - 2011-06-16
     'LinkedMonitors'        => 'Lingitud monitorid',
     'List'                  => 'List',
+    'ListMatches'          => 'List Matches',           // Added - 2018-08-30
     'Load'                  => 'Koormus',
     'Local'                 => 'Local',
     'Log'                   => 'Logi',                    // Added - 2011-06-16
@@ -491,6 +515,7 @@ $SLANG = array(
     'MonitorProbeIntro'     => 'The list below shows detected analog and network cameras and whether they are already being used or available for selection.<br/><br/>Select the desired entry from the list below.<br/><br/>Please note that not all cameras may be detected and that choosing a camera here may overwrite any values you already have configured for the current monitor.<br/><br/>',
     'Monitors'              => 'Monitors',
     'Montage'               => 'Montage',
+    'MontageReview'        => 'Montage Review',         // Added - 2018-08-30
     'Month'                 => 'Kuus',
     'More'                  => 'Veel',                   // Added - 2011-06-16
     'MotionFrameSkip'       => 'Motion Frame Skip',
@@ -517,6 +542,7 @@ $SLANG = array(
     'Next'                  => 'Järgmine',
     'No'                    => 'Ei',
     'NoDetectedCameras'     => 'Ei leidnud kaameraid',
+    'NoDetectedProfiles'   => 'No Detected Profiles',   // Added - 2018-08-30
     'NoFramesRecorded'      => 'Ei ole kaadreid salvetatud selles sündmuses',
     'NoGroup'               => 'Ei krupp',
     'NoSavedFilters'        => 'EiSalvestatudFiltreid',
@@ -535,6 +561,8 @@ $SLANG = array(
     'OpGt'                  => 'Suurem kui',
     'OpGtEq'                => 'suurem kui või võrdne',
     'OpIn'                  => 'in set',
+    'OpIs'                 => 'is',                     // Added - 2018-08-30
+    'OpIsNot'              => 'is not',                 // Added - 2018-08-30
     'OpLt'                  => 'vähem kui',
     'OpLtEq'                => 'vähem kui või võrdne',
     'OpMatches'             => 'klapib',
@@ -544,6 +572,7 @@ $SLANG = array(
     'Open'                  => 'Ava',
     'OptionHelp'            => 'Valik Aita',
     'OptionRestartWarning'  => 'These changes may not come into effect fully\nwhile the system is running. When you have\nfinished making your changes please ensure that\nyou restart ZoneMinder.',
+    'OptionalEncoderParam' => 'Optional Encoder Parameters', // Added - 2018-08-30
     'Options'               => 'Seaded',
     'OrEnterNewName'        => 'või sisesta uus nimi',
     'Order'                 => 'Järjekord',
@@ -581,9 +610,13 @@ $SLANG = array(
     'ProfileProbeIntro'    => 'The list below shows the existing stream profiles of the selected camera .<br/><br/>Select the desired entry from the list below.<br/><br/>Please note that ZoneMinder cannot configure additional profiles and that choosing a camera here may overwrite any values you already have configured for the current monitor.<br/><br/>', // Added - 2015-04-18
     'Progress'             => 'Progress',               // Added - 2015-04-18
     'Protocol'              => 'Protocol',
+    'RTSPDescribe'         => 'Use RTSP Response Media URL', // Added - 2018-08-30
+    'RTSPTransport'        => 'RTSP Transport Protocol', // Added - 2018-08-30
     'Rate'                  => 'Rate',
     'Real'                  => 'Reaaalne',
+    'RecaptchaWarning'     => 'Your reCaptcha secret key is invalid. Please correct it, or reCaptcha will not work', // Added - 2018-08-30
     'Record'                => 'Salvesta',
+    'RecordAudio'          => 'Whether to store the audio stream when saving an event.', // Added - 2018-08-30
     'RefImageBlendPct'      => 'Reference Image Blend %ge',
     'Refresh'               => 'Värskenda',
     'Remote'                => 'Remote',
@@ -599,6 +632,7 @@ $SLANG = array(
     'ReplayAll'             => 'Kõik sündmused',
     'ReplayGapless'         => 'Lünkadeta sündmused',
     'ReplaySingle'          => 'Üksik sündmus',
+    'ReportEventAudit'     => 'Audit Events Report',    // Added - 2018-08-30
     'Reset'                 => 'Reset',
     'ResetEventCounts'      => 'Reset Event Counts',
     'Restart'               => 'Taaskäivita',
@@ -617,6 +651,7 @@ $SLANG = array(
     'Save'                  => 'Salvesta',
     'SaveAs'                => 'Salvesta kui',
     'SaveFilter'            => 'Salvesta Filter',
+    'SaveJPEGs'            => 'Save JPEGs',             // Added - 2018-08-30
     'Scale'                 => 'Skaala',
     'Score'                 => 'Skoor',
     'Secs'                  => 'Secs',
@@ -633,6 +668,7 @@ $SLANG = array(
     'ShowFilterWindow'      => 'Näita Filtri Akent',
     'ShowTimeline'          => 'Näita Timeline',
     'SignalCheckColour'     => 'Signaali Kontroll Värv',
+    'SignalCheckPoints'    => 'Signal Check Points',    // Added - 2018-08-30
     'Size'                  => 'Suurus',
     'SkinDescription'       => 'Vaheta veebilehe välimus selles arvutis', // Added - 2011-03-02
     'Sleep'                 => 'Maga',
@@ -652,6 +688,10 @@ $SLANG = array(
     'State'                 => 'Olek',
     'Stats'                 => 'Statistika',
     'Status'                => 'Staatus',
+    'StatusConnected'      => 'Capturing',              // Added - 2018-08-30
+    'StatusNotRunning'     => 'Not Running',            // Added - 2018-08-30
+    'StatusRunning'        => 'Not Capturing',          // Added - 2018-08-30
+    'StatusUnknown'        => 'Unknown',                // Added - 2018-08-30
     'Step'                  => 'Samm',
     'StepBack'              => 'Samm tagasi',
     'StepForward'           => 'Samm edasi',
@@ -662,6 +702,8 @@ $SLANG = array(
     'Stills'                => 'Stills',
     'Stop'                  => 'Stop',
     'Stopped'               => 'Stopitud',
+    'StorageArea'          => 'Storage Area',           // Added - 2018-08-30
+    'StorageScheme'        => 'Scheme',                 // Added - 2018-08-30
     'Stream'                => 'Striim',
     'StreamReplayBuffer'    => 'Striimi Replay Pildi Puhver',
     'Submit'                => 'Submit',
@@ -681,6 +723,7 @@ $SLANG = array(
     'TimelineTip4'          => 'Use the controls below to zoom out or navigate back and forward through the time range.',              // Added 2013.08.15.
     'Timestamp'             => 'Timestamp',
     'TimestampLabelFormat'  => 'Timestamp Label Format',
+    'TimestampLabelSize'   => 'Font Size',              // Added - 2018-08-30
     'TimestampLabelX'       => 'Timestamp Label X',
     'TimestampLabelY'       => 'Timestamp Label Y',
     'Today'                 => 'Täna',
@@ -727,6 +770,7 @@ $SLANG = array(
     'VideoGenParms'         => 'Video Genereerimise Parameetrid',
     'VideoGenSucceeded'     => 'Video Genereerimine Õnnestus!!!',
     'VideoSize'             => 'Video Suurus',
+    'VideoWriter'          => 'Video Writer',           // Added - 2018-08-30
     'View'                  => 'Vaata',
     'ViewAll'               => 'View All',
     'ViewEvent'             => 'Vaata Sündmust',
@@ -736,6 +780,7 @@ $SLANG = array(
     'Watch'                 => 'Vaata',
     'Web'                   => 'Veeb',
     'WebColour'             => 'Veebi värv',
+    'WebSiteUrl'           => 'Website URL',            // Added - 2018-08-30
     'Week'                  => 'Nädalas',
     'White'                 => 'White',
     'WhiteBalance'          => 'White Balance',
