@@ -83,6 +83,8 @@ $SLANG = array(
     'Actual'               => 'Attuale',
     'AddNewControl'        => 'Aggiungi nuovo Controllo',
     'AddNewMonitor'        => 'Aggiungi nuovo Monitor',
+    'AddNewServer'         => 'Add New Server',         // Added - 2018-08-30
+    'AddNewStorage'        => 'Add New Storage',        // Added - 2018-08-30
     'AddNewUser'           => 'Aggiungi nuovo Utente',
     'AddNewZone'           => 'Aggiungi nuova Zona',
     'Alarm'                => 'Allarme',
@@ -110,22 +112,32 @@ $SLANG = array(
     'AttrArchiveStatus'    => 'Stato Archivio',
     'AttrAvgScore'         => 'Punteggio medio',
     'AttrCause'            => 'Causa',
-    'AttrDate'             => 'Data',
-    'AttrDateTime'         => 'Data/Ora',
     'AttrDiskBlocks'       => 'Blocchi del Disco',
     'AttrDiskPercent'      => 'Percentuale del Disco',
+    'AttrDiskSpace'        => 'Disk Space',             // Added - 2018-08-30
     'AttrDuration'         => 'Durata',
+    'AttrEndDate'          => 'End Date',               // Added - 2018-08-30
+    'AttrEndDateTime'      => 'End Date/Time',          // Added - 2018-08-30
+    'AttrEndTime'          => 'End Time',               // Added - 2018-08-30
+    'AttrEndWeekday'       => 'End Weekday',            // Added - 2018-08-30
+    'AttrFilterServer'     => 'Server Filter is Running On', // Added - 2018-08-30
     'AttrFrames'           => 'Immagini',
     'AttrId'               => 'Id',
     'AttrMaxScore'         => 'Punteggio massimo',
     'AttrMonitorId'        => 'Id Monitor',
     'AttrMonitorName'      => 'Nome Monitor',
+    'AttrMonitorServer'    => 'Server Monitor is Running On', // Added - 2018-08-30
     'AttrName'             => 'Nome',
     'AttrNotes'            => 'Note',
+    'AttrStartDate'        => 'Start Date',             // Added - 2018-08-30
+    'AttrStartDateTime'    => 'Start Date/Time',        // Added - 2018-08-30
+    'AttrStartTime'        => 'Start Time',             // Added - 2018-08-30
+    'AttrStartWeekday'     => 'Start Weekday',          // Added - 2018-08-30
+    'AttrStateId'          => 'Run State',              // Added - 2018-08-30
+    'AttrStorageArea'      => 'Storage Area',           // Added - 2018-08-30
+    'AttrStorageServer'    => 'Server Hosting Storage', // Added - 2018-08-30
     'AttrSystemLoad'       => 'System Load',
-    'AttrTime'             => 'Ora',
     'AttrTotalScore'       => 'Punteggio totale',
-    'AttrWeekday'          => 'Giorno della settimana',
     'Auto'                 => 'Auto',
     'AutoStopTimeout'      => 'Auto Stop Timeout',
     'Available'            => 'Disponibile',              // Added - 2009-03-31
@@ -158,9 +170,11 @@ $SLANG = array(
     'BadRefBlendPerc'      => 'La percentuale di miscela di riferimento deve essere un intero positivo',
     'BadSectionLength'     => 'La lunghezza della sezione deve essere un numero intero pari a 30 o maggiore',
     'BadSignalCheckColour' => 'Signal check colour must be a valid RGB colour string',
+    'BadSourceType'        => 'Source Type \"Web Site\" requires the Function to be set to \"Monitor\"', // Added - 2018-08-30
     'BadStreamReplayBuffer'=> 'Stream replay buffer must be an integer of zero or more',
     'BadWarmupCount'       => 'Il numero di frame di allarme deve essere un numero intero maggiore o uguale a zero',
     'BadWebColour'         => 'L\'identificativo del colore deve essere una stringa valida', 
+    'BadWebSitePath'       => 'Please enter a complete website url, including the http:// or https:// prefix.', // Added - 2018-08-30
     'BadWidth'             => 'La larghezza deve essere impostata con un valore valido',
     'Bandwidth'            => 'Banda',
     'BandwidthHead'         => 'Bandwidth',	// This is the end of the bandwidth status on the top of the console, different in many language due to phrasing
@@ -224,10 +238,12 @@ $SLANG = array(
     'ChooseLogSelection'   => 'Choose a log selection', // Added - 2011-06-17
     'ChoosePreset'         => 'Scegli Preset',
     'Clear'                => 'Clear',                  // Added - 2011-06-16
+    'CloneMonitor'         => 'Clone',                  // Added - 2018-08-30
     'Close'                => 'Chiudi',
     'Colour'               => 'Colori',
     'Command'              => 'Comando',
     'Component'            => 'Component',              // Added - 2011-06-16
+    'ConcurrentFilter'     => 'Run filter concurrently', // Added - 2018-08-30
     'Config'               => 'Configura',
     'ConfiguredFor'        => 'Configurato per',
     'ConfirmDeleteEvents'  => 'Sei sicuro di voler cancellare gli eventi selezionati',
@@ -285,9 +301,11 @@ $SLANG = array(
     'DonateRemindWeek'     => 'Non ancora, ricordamelo ancora tra 1 settimana',
     'DonateYes'            => 'Si,mi piacerebbe donare qualcosa ora',
     'Download'             => 'Download',
+    'DownloadVideo'        => 'Download Video',         // Added - 2018-08-30
     'DuplicateMonitorName' => 'Il nome del monitor e\' gia\' presente', // Added - 2009-03-31
     'Duration'             => 'Durata',
     'Edit'                 => 'Modifica',
+    'EditLayout'           => 'Edit Layout',            // Added - 2018-08-30
     'Email'                => 'Email',
     'EnableAlarms'         => 'Abilita Allarmi',
     'Enabled'              => 'Attivo',
@@ -304,6 +322,7 @@ $SLANG = array(
     'Events'               => 'Eventi',
     'Exclude'              => 'Escludi',
     'Execute'              => 'Esegui',
+    'Exif'                 => 'Embed EXIF data into image', // Added - 2018-08-30
     'Export'               => 'Esporta',
     'ExportDetails'        => 'Esp. dettagli eventi',
     'ExportFailed'         => 'Esp. Fallita ',
@@ -333,8 +352,10 @@ $SLANG = array(
     'FilterExecuteEvents'  => 'Esegui un comando',
     'FilterLog'            => 'Filter log',             // Added - 2015-04-18
     'FilterMessageEvents'  => 'Invia dettagli tramite messaggio',
+    'FilterMoveEvents'     => 'Move all matches',       // Added - 2018-08-30
     'FilterPx'             => 'Px Filtro',
     'FilterUnset'          => 'Devi specificare altezza e larghezza per il filtro',
+    'FilterUpdateDiskSpace'=> 'Update used disk space', // Added - 2018-08-30
     'FilterUploadEvents'   => 'Fai upload eventi (FTP)',
     'FilterVideoEvents'    => 'Crea video per tutte le corrispondenze',
     'Filters'              => 'Filtri',
@@ -359,6 +380,7 @@ $SLANG = array(
     'Function'             => 'Funzione',
     'Gain'                 => 'Gain',
     'General'              => 'Generale',
+    'GenerateDownload'     => 'Generate Download',      // Added - 2018-08-30
     'GenerateVideo'        => 'Genera Video',
     'GeneratingVideo'      => 'Sto generando il Video',
     'GoToZoneMinder'       => 'Vai su zoneminder.com',
@@ -379,6 +401,7 @@ $SLANG = array(
     'High'                 => 'Alta',
     'HighBW'               => 'Banda&nbsp;Alta',
     'Home'                 => 'Home',
+    'Hostname'             => 'Hostname',               // Added - 2018-08-30
     'Hour'                 => 'Ora',
     'Hue'                  => 'Tinta',
     'Id'                   => 'Id',
@@ -403,6 +426,7 @@ $SLANG = array(
     'Line'                 => 'Line',                   // Added - 2011-06-16
     'LinkedMonitors'       => 'Monitor Collegati',
     'List'                 => 'Lista',
+    'ListMatches'          => 'List Matches',           // Added - 2018-08-30
     'Load'                 => 'Carico Sistema',
     'Local'                => 'Locale',
     'Log'                  => 'Log',                    // Added - 2011-06-16
@@ -489,6 +513,7 @@ $SLANG = array(
     'MonitorProbeIntro'    => 'The list below shows detected analog and network cameras and whether they are already being used or available for selection.<br/><br/>Select the desired entry from the list below.<br/><br/>Please note that not all cameras may be detected and that choosing a camera here may overwrite any values you already have configured for the current monitor.<br/><br/>', // Added - 2009-03-31
     'Monitors'             => 'Monitors',
     'Montage'              => 'Montaggio',
+    'MontageReview'        => 'Montage Review',         // Added - 2018-08-30
     'Month'                => 'Mese',
     'More'                 => 'More',                   // Added - 2011-06-16
     'MotionFrameSkip'      => 'Motion Frame Skip',
@@ -515,6 +540,7 @@ $SLANG = array(
     'Next'                 => 'Prossimo',
     'No'                   => 'No',
     'NoDetectedCameras'    => 'Nessuna telecamera rilevata',    // Added - 2009-03-31
+    'NoDetectedProfiles'   => 'No Detected Profiles',   // Added - 2018-08-30
     'NoFramesRecorded'     => 'Non ci sono immagini salvate per questo evento',
     'NoGroup'              => 'Nessun gruppo',               // Added - 2009-02-08
     'NoSavedFilters'       => 'NessunFiltroSalvato',
@@ -533,6 +559,8 @@ $SLANG = array(
     'OpGt'                 => 'maggiore di',
     'OpGtEq'               => 'maggiore o uguale a',
     'OpIn'                 => 'impostato',
+    'OpIs'                 => 'is',                     // Added - 2018-08-30
+    'OpIsNot'              => 'is not',                 // Added - 2018-08-30
     'OpLt'                 => 'minore di',
     'OpLtEq'               => 'minore o uguale a',
     'OpMatches'            => 'corrisponde',
@@ -542,6 +570,7 @@ $SLANG = array(
     'Open'                 => 'Apri',
     'OptionHelp'           => 'Opzioni di Aiuto',
     'OptionRestartWarning' => 'Queste modifiche potrebbero essere attive solo dopo un riavvio del sistema. Riavviare ZoneMinder.',
+    'OptionalEncoderParam' => 'Optional Encoder Parameters', // Added - 2018-08-30
     'Options'              => 'Opzioni',
     'OrEnterNewName'       => 'o inserisci un nuovo nome',
     'Order'                => 'Ordine',
@@ -579,9 +608,13 @@ $SLANG = array(
     'ProfileProbeIntro'    => 'The list below shows the existing stream profiles of the selected camera .<br/><br/>Select the desired entry from the list below.<br/><br/>Please note that ZoneMinder cannot configure additional profiles and that choosing a camera here may overwrite any values you already have configured for the current monitor.<br/><br/>', // Added - 2015-04-18
     'Progress'             => 'Progress',               // Added - 2015-04-18
     'Protocol'             => 'Protocol',
+    'RTSPDescribe'         => 'Use RTSP Response Media URL', // Added - 2018-08-30
+    'RTSPTransport'        => 'RTSP Transport Protocol', // Added - 2018-08-30
     'Rate'                 => 'Velocita\'',
     'Real'                 => 'Reale',
+    'RecaptchaWarning'     => 'Your reCaptcha secret key is invalid. Please correct it, or reCaptcha will not work', // Added - 2018-08-30
     'Record'               => 'Registra',
+    'RecordAudio'          => 'Whether to store the audio stream when saving an event.', // Added - 2018-08-30
     'RefImageBlendPct'     => 'Riferimento Miscela Immagine percentuale',
     'Refresh'              => 'Aggiorna',
     'Remote'               => 'Remoto',
@@ -597,6 +630,7 @@ $SLANG = array(
     'ReplayAll'            => 'All Events',
     'ReplayGapless'        => 'Gapless Events',
     'ReplaySingle'         => 'Single Event',
+    'ReportEventAudit'     => 'Audit Events Report',    // Added - 2018-08-30
     'Reset'                => 'Resetta',
     'ResetEventCounts'     => 'Resetta Contatore Eventi',
     'Restart'              => 'Riavvia',
@@ -615,6 +649,7 @@ $SLANG = array(
     'Save'                 => 'Salva',
     'SaveAs'               => 'Salva come',
     'SaveFilter'           => 'salva Filtro',
+    'SaveJPEGs'            => 'Save JPEGs',             // Added - 2018-08-30
     'Scale'                => 'Scala',
     'Score'                => 'Punteggio',
     'Secs'                 => 'Secs',
@@ -631,6 +666,7 @@ $SLANG = array(
     'ShowFilterWindow'     => 'MostraFinestraFiltri',
     'ShowTimeline'         => 'Mostra linea temporale',
     'SignalCheckColour'    => 'Signal Check Colour',
+    'SignalCheckPoints'    => 'Signal Check Points',    // Added - 2018-08-30
     'Size'                 => 'grandezza',
     'SkinDescription'      => 'Change the default skin for this computer', // Added - 2011-01-30
     'Sleep'                => 'Sleep',
@@ -650,6 +686,10 @@ $SLANG = array(
     'State'                => 'Stato',
     'Stats'                => 'Statistiche',
     'Status'               => 'Stato',
+    'StatusConnected'      => 'Capturing',              // Added - 2018-08-30
+    'StatusNotRunning'     => 'Not Running',            // Added - 2018-08-30
+    'StatusRunning'        => 'Not Capturing',          // Added - 2018-08-30
+    'StatusUnknown'        => 'Unknown',                // Added - 2018-08-30
     'Step'                 => 'Passo',
     'StepBack'             => 'Step Back',
     'StepForward'          => 'Step Forward',
@@ -660,6 +700,8 @@ $SLANG = array(
     'Stills'               => 'Foto',
     'Stop'                 => 'Stop',
     'Stopped'              => 'Inattivo',
+    'StorageArea'          => 'Storage Area',           // Added - 2018-08-30
+    'StorageScheme'        => 'Scheme',                 // Added - 2018-08-30
     'Stream'               => 'Flusso',
     'StreamReplayBuffer'   => 'Stream Replay Image Buffer',
     'Submit'               => 'Accetta',
@@ -679,6 +721,7 @@ $SLANG = array(
     'TimelineTip4'          => 'Use the controls below to zoom out or navigate back and forward through the time range.',              // Added 2013.08.15.
     'Timestamp'            => 'Timestamp',
     'TimestampLabelFormat' => 'Formato etichetta timestamp',
+    'TimestampLabelSize'   => 'Font Size',              // Added - 2018-08-30
     'TimestampLabelX'      => 'coordinata X etichetta',
     'TimestampLabelY'      => 'coordinata Y etichetta',
     'Today'                => 'Oggi ',
@@ -725,6 +768,7 @@ $SLANG = array(
     'VideoGenParms'        => 'Parametri Generazione Video',
     'VideoGenSucceeded'    => 'Successo: Generato Video  !',
     'VideoSize'            => 'Dimensioni Video',
+    'VideoWriter'          => 'Video Writer',           // Added - 2018-08-30
     'View'                 => 'vedi',
     'ViewAll'              => 'Vedi Tutto',
     'ViewEvent'            => 'Vedi Evento',
@@ -734,6 +778,7 @@ $SLANG = array(
     'Watch'                => 'Guarda',
     'Web'                  => 'Web',
     'WebColour'            => 'Colore Web',
+    'WebSiteUrl'           => 'Website URL',            // Added - 2018-08-30
     'Week'                 => 'Settimana',
     'White'                => 'Bianco',
     'WhiteBalance'         => 'Bil. Bianco  ',
