@@ -79,6 +79,8 @@ $SLANG = array(
     'Actual'               => 'Origineel',
     'AddNewControl'        => 'Nieuwe controle toevoegen',
     'AddNewMonitor'        => 'Nieuwe monitor toevoegen',
+    'AddNewServer'         => 'Add New Server',         // Added - 2018-08-30
+    'AddNewStorage'        => 'Add New Storage',        // Added - 2018-08-30
     'AddNewUser'           => 'Nieuwe gebruiker toevoegen',
     'AddNewZone'           => 'Nieuw gebied toevoegen',
     'Alarm'                => 'Alarm',
@@ -106,22 +108,32 @@ $SLANG = array(
     'AttrArchiveStatus'    => 'Archiefstatus',
     'AttrAvgScore'         => 'Gem. score',
     'AttrCause'            => 'Oorzaak',
-    'AttrDate'             => 'Datum',
-    'AttrDateTime'         => 'Datum/tijd',
     'AttrDiskBlocks'       => 'Disk Blocks',
     'AttrDiskPercent'      => 'Disk Percent',
+    'AttrDiskSpace'        => 'Disk Space',             // Added - 2018-08-30
     'AttrDuration'         => 'Duur',
+    'AttrEndDate'          => 'End Date',               // Added - 2018-08-30
+    'AttrEndDateTime'      => 'End Date/Time',          // Added - 2018-08-30
+    'AttrEndTime'          => 'End Time',               // Added - 2018-08-30
+    'AttrEndWeekday'       => 'End Weekday',            // Added - 2018-08-30
+    'AttrFilterServer'     => 'Server Filter is Running On', // Added - 2018-08-30
     'AttrFrames'           => 'Frames',
     'AttrId'               => 'Id',
     'AttrMaxScore'         => 'Max. Score',
     'AttrMonitorId'        => 'Monitor Id',
     'AttrMonitorName'      => 'Monitor Naam',
+    'AttrMonitorServer'    => 'Server Monitor is Running On', // Added - 2018-08-30
     'AttrName'             => 'Naam',
     'AttrNotes'            => 'Notities',
+    'AttrStartDate'        => 'Start Date',             // Added - 2018-08-30
+    'AttrStartDateTime'    => 'Start Date/Time',        // Added - 2018-08-30
+    'AttrStartTime'        => 'Start Time',             // Added - 2018-08-30
+    'AttrStartWeekday'     => 'Start Weekday',          // Added - 2018-08-30
+    'AttrStateId'          => 'Run State',              // Added - 2018-08-30
+    'AttrStorageArea'      => 'Storage Area',           // Added - 2018-08-30
+    'AttrStorageServer'    => 'Server Hosting Storage', // Added - 2018-08-30
     'AttrSystemLoad'       => 'Systembelasting',
-    'AttrTime'             => 'Tijd',
     'AttrTotalScore'       => 'Totale Score',
-    'AttrWeekday'          => 'Weekdag',
     'Auto'                 => 'Auto',
     'AutoStopTimeout'      => 'Auto Stop Timeout',
     'Available'            => 'Beschikbaar',
@@ -154,9 +166,11 @@ $SLANG = array(
     'BadRefBlendPerc'      => 'Reference blend percentage moet een geldige waarde van nul of groter zijn',
     'BadSectionLength'     => 'Sectielengte moet een getal van 30 of groter zijn',
     'BadSignalCheckColour' => 'Signaalcontrolekleur moet een geldige RGB waarde zijn',
+    'BadSourceType'        => 'Source Type \"Web Site\" requires the Function to be set to \"Monitor\"', // Added - 2018-08-30
     'BadStreamReplayBuffer'=> 'Stream replay buffer moet een geldige waarde van nul of groter zijn',
     'BadWarmupCount'       => 'Opwarm frames moet een geldig getal van nul of groter zijn',
     'BadWebColour'         => 'Webkleur moet een geldige webkleurwaarde bevatten',
+    'BadWebSitePath'       => 'Please enter a complete website url, including the http:// or https:// prefix.', // Added - 2018-08-30
     'BadWidth'             => 'Breedte moet een geldige waarde zijn',
     'Bandwidth'            => 'Bandbreedte',
     'BandwidthHead'        => 'bandbreedte',	// This is the end of the bandwidth status on the top of the console, different in many language due to phrasing
@@ -220,10 +234,12 @@ $SLANG = array(
     'ChooseLogSelection'   => 'Kies een logselectie',
     'ChoosePreset'         => 'Kies voorkeur',
     'Clear'                => 'Legen',
+    'CloneMonitor'         => 'Clone',                  // Added - 2018-08-30
     'Close'                => 'Sluiten',
     'Colour'               => 'Kleur',
     'Command'              => 'Commando',
     'Component'            => 'Component',
+    'ConcurrentFilter'     => 'Run filter concurrently', // Added - 2018-08-30
     'Config'               => 'Configuratie',
     'ConfiguredFor'        => 'Geconfigureerd voor',
     'ConfirmDeleteEvents'  => 'Weet u zeker dat u deze gebeurtenissen wilt verwijderen?',
@@ -281,9 +297,11 @@ $SLANG = array(
     'DonateRemindWeek'     => 'Nu niet, herinner mij over een week hieraan',
     'DonateYes'            => 'Ja, ik wil nu doneren',
     'Download'             => 'Downloaden',
+    'DownloadVideo'        => 'Download Video',         // Added - 2018-08-30
     'DuplicateMonitorName' => 'Kopieer monitornaam',
     'Duration'             => 'Duur',
     'Edit'                 => 'Bewerken',
+    'EditLayout'           => 'Edit Layout',            // Added - 2018-08-30
     'Email'                => 'Email',
     'EnableAlarms'         => 'Alarmen inschakelen',
     'Enabled'              => 'Ingeschakeld',
@@ -300,6 +318,7 @@ $SLANG = array(
     'Events'               => 'Gebeurtenissen',
     'Exclude'              => 'Uitsluiten',
     'Execute'              => 'Uitvoeren',
+    'Exif'                 => 'Embed EXIF data into image', // Added - 2018-08-30
     'Export'               => 'Exporteren',
     'ExportDetails'        => 'Exporteer gebeurtenisdetails',
     'ExportFailed'         => 'Exporteren mislukt',
@@ -329,8 +348,10 @@ $SLANG = array(
     'FilterExecuteEvents'  => 'Voer opdrachten uit op alle overeenkomsten',
     'FilterLog'            => 'Filterlog',
     'FilterMessageEvents'  => 'Bericht de details van alle overeenkomsten',
+    'FilterMoveEvents'     => 'Move all matches',       // Added - 2018-08-30
     'FilterPx'             => 'Filter px',
     'FilterUnset'          => 'Je moet de filterhoogte en -breedte opgeven',
+    'FilterUpdateDiskSpace'=> 'Update used disk space', // Added - 2018-08-30
     'FilterUploadEvents'   => 'Verstuur alle overeenkomsten',
     'FilterVideoEvents'    => 'Maak video voor alle overeenkomsten',
     'Filters'              => 'Filters',
@@ -355,6 +376,7 @@ $SLANG = array(
     'Function'             => 'Functie',
     'Gain'                 => 'Gain',
     'General'              => 'Algemeen',
+    'GenerateDownload'     => 'Generate Download',      // Added - 2018-08-30
     'GenerateVideo'        => 'Genereer Video',
     'GeneratingVideo'      => 'Video wordt gegenereerd',
     'GoToZoneMinder'       => 'Ga naar ZoneMinder.com',
@@ -375,6 +397,7 @@ $SLANG = array(
     'High'                 => 'Hoog',
     'HighBW'               => 'Hoog&nbsp;B/W',
     'Home'                 => 'Home',
+    'Hostname'             => 'Hostname',               // Added - 2018-08-30
     'Hour'                 => 'Uur',
     'Hue'                  => 'Hue',
     'Id'                   => 'Id',
@@ -399,6 +422,7 @@ $SLANG = array(
     'Line'                 => 'Lijn',
     'LinkedMonitors'       => 'Gekoppelde monitoren',
     'List'                 => 'Lijst',
+    'ListMatches'          => 'List Matches',           // Added - 2018-08-30
     'Load'                 => 'Systeemlast',
     'Local'                => 'Lokaal',
     'Log'                  => 'Log',
@@ -485,6 +509,7 @@ $SLANG = array(
     'MonitorProbeIntro'    => 'Deze lijst toont gedeteerde analoge en netwerk cameras en of deze al in gebruik of beschikbaar zijn.<br/><br/>Selecteer de gewenste waarde uit de lijst hieronder.<br/><br/>Let op dat mogelijk niet alle cameras hier worden weergegeven en dat alle ingevoerde waarden voor de huidige monitor zullen worden overschreven.<br/><br/>',
     'Monitors'             => 'Monitoren',
     'Montage'              => 'Montage',
+    'MontageReview'        => 'Montage Review',         // Added - 2018-08-30
     'Month'                => 'Maand',
     'More'                 => 'Meer',
     'MotionFrameSkip'      => 'Motion Frame Skip',
@@ -511,6 +536,7 @@ $SLANG = array(
     'Next'                 => 'Volgende',
     'No'                   => 'Nee',
     'NoDetectedCameras'    => 'Geen cameras gedetecteerd',
+    'NoDetectedProfiles'   => 'No Detected Profiles',   // Added - 2018-08-30
     'NoFramesRecorded'     => 'Er zijn geen beelden opgenomen voor deze gebeurtenis',
     'NoGroup'              => 'Geen Groep',
     'NoSavedFilters'       => 'Geen Opgeslagen Filters',
@@ -529,6 +555,8 @@ $SLANG = array(
     'OpGt'                 => 'groter dan',
     'OpGtEq'               => 'groter dan of gelijk aan',
     'OpIn'                 => 'in set',
+    'OpIs'                 => 'is',                     // Added - 2018-08-30
+    'OpIsNot'              => 'is not',                 // Added - 2018-08-30
     'OpLt'                 => 'kleiner dan',
     'OpLtEq'               => 'kleiner dan of gelijk aan',
     'OpMatches'            => 'Komt overeen met',
@@ -538,6 +566,7 @@ $SLANG = array(
     'Open'                 => 'Open',
     'OptionHelp'           => 'OptieHelp',
     'OptionRestartWarning' => 'Deze veranderingen worden niet\ndoorgevoerd als het systeem loopt.\nVergeet niet ZoneMinder te herstarten\nwanneer u klaar bent.',
+    'OptionalEncoderParam' => 'Optional Encoder Parameters', // Added - 2018-08-30
     'Options'              => 'Opties',
     'OrEnterNewName'       => 'of voer een nieuwe naam in',
     'Order'                => 'Sorteren',
@@ -575,9 +604,13 @@ $SLANG = array(
     'ProfileProbeIntro'    => 'The list below shows the existing stream profiles of the selected camera .<br/><br/>Select the desired entry from the list below.<br/><br/>Please note that ZoneMinder cannot configure additional profiles and that choosing a camera here may overwrite any values you already have configured for the current monitor.<br/><br/>', // Added - 2015-04-18
     'Progress'             => 'Voortgang',
     'Protocol'             => 'Protocol',
+    'RTSPDescribe'         => 'Use RTSP Response Media URL', // Added - 2018-08-30
+    'RTSPTransport'        => 'RTSP Transport Protocol', // Added - 2018-08-30
     'Rate'                 => 'Snelheid',
     'Real'                 => 'Echte',
+    'RecaptchaWarning'     => 'Your reCaptcha secret key is invalid. Please correct it, or reCaptcha will not work', // Added - 2018-08-30
     'Record'               => 'Record',
+    'RecordAudio'          => 'Whether to store the audio stream when saving an event.', // Added - 2018-08-30
     'RefImageBlendPct'     => 'Referentie beeld blend percentage',
     'Refresh'              => 'Verversen',
     'Remote'               => 'Remote',
@@ -593,6 +626,7 @@ $SLANG = array(
     'ReplayAll'            => 'Alle Gebeurtenissen',
     'ReplayGapless'        => 'Opvolgende Gebeurtenissen',
     'ReplaySingle'         => 'Enkele Gebeurtenis',
+    'ReportEventAudit'     => 'Audit Events Report',    // Added - 2018-08-30
     'Reset'                => 'Resetten',
     'ResetEventCounts'     => 'Gebeurtenisteller resetten',
     'Restart'              => 'Herstart',
@@ -611,6 +645,7 @@ $SLANG = array(
     'Save'                 => 'Opslaan',
     'SaveAs'               => 'Opslaan als',
     'SaveFilter'           => 'Filter opslaan',
+    'SaveJPEGs'            => 'Save JPEGs',             // Added - 2018-08-30
     'Scale'                => 'Schaal',
     'Score'                => 'Score',
     'Secs'                 => 'Sec.',
@@ -627,6 +662,7 @@ $SLANG = array(
     'ShowFilterWindow'     => 'Toon Filtervenster',
     'ShowTimeline'         => 'Toon Tijdlijn',
     'SignalCheckColour'    => 'Signaalcontrolekleur',
+    'SignalCheckPoints'    => 'Signal Check Points',    // Added - 2018-08-30
     'Size'                 => 'Groote',
     'SkinDescription'      => 'Wijzig standaarduiterlijk voor deze computer',
     'Sleep'                => 'Slaap',
@@ -646,6 +682,10 @@ $SLANG = array(
     'State'                => 'Status',
     'Stats'                => 'Stats',
     'Status'               => 'Status',
+    'StatusConnected'      => 'Capturing',              // Added - 2018-08-30
+    'StatusNotRunning'     => 'Not Running',            // Added - 2018-08-30
+    'StatusRunning'        => 'Not Capturing',          // Added - 2018-08-30
+    'StatusUnknown'        => 'Unknown',                // Added - 2018-08-30
     'Step'                 => 'Stap',
     'StepBack'             => 'Stap Terug',
     'StepForward'          => 'Stap Vooruit',
@@ -656,6 +696,8 @@ $SLANG = array(
     'Stills'               => 'Beelden',
     'Stop'                 => 'Stoppen',
     'Stopped'              => 'Gestopt',
+    'StorageArea'          => 'Storage Area',           // Added - 2018-08-30
+    'StorageScheme'        => 'Scheme',                 // Added - 2018-08-30
     'Stream'               => 'Stream',
     'StreamReplayBuffer'   => 'Stream Replay beeldbuffer',
     'Submit'               => 'Verzenden',
@@ -675,6 +717,7 @@ $SLANG = array(
     'TimelineTip4'         => 'Gebruik de knoppen hieronder om uit te zoomen of voor- en achteruit te navigeren.',
     'Timestamp'            => 'Tijdstempel',
     'TimestampLabelFormat' => 'Formaat tijdstempel',
+    'TimestampLabelSize'   => 'Font Size',              // Added - 2018-08-30
     'TimestampLabelX'      => 'Tijdstempel X-positie',
     'TimestampLabelY'      => 'Tijdstempel Y-positie',
     'Today'                => 'Vandaag',
@@ -721,6 +764,7 @@ $SLANG = array(
     'VideoGenParms'        => 'Videogeneratie Parameters',
     'VideoGenSucceeded'    => 'Videogeneratie voltooid!',
     'VideoSize'            => 'Videogrootte',
+    'VideoWriter'          => 'Video Writer',           // Added - 2018-08-30
     'View'                 => 'Bekijk',
     'ViewAll'              => 'Bekijk Alles',
     'ViewEvent'            => 'Bekijk Gebeurtenis',
@@ -730,6 +774,7 @@ $SLANG = array(
     'Watch'                => 'Observeer',
     'Web'                  => 'Web',
     'WebColour'            => 'Webkleur',
+    'WebSiteUrl'           => 'Website URL',            // Added - 2018-08-30
     'Week'                 => 'Week',
     'White'                => 'Wit',
     'WhiteBalance'         => 'Witbalans',
