@@ -4,7 +4,7 @@
 //
 // Feel Free to contact Me at illuminati@linuxmail.org
 //
-// Traduo Para Portugus do Brasil do Zoneminder
+// Tradução Para Português do Brasil do Zoneminder
 //
 // Sinta-se Livre para me contactar em illuminati@linuxmail.org 
 
@@ -18,7 +18,9 @@ $SLANG = array(
     'Actual'               => 'Atual',
     'AddNewControl'        => 'Add New Control',
     'AddNewMonitor'        => 'Adicionar Monitor',
-    'AddNewUser'           => 'Adicionar Usurio',
+    'AddNewServer'         => 'Add New Server',         // Added - 2018-08-30
+    'AddNewStorage'        => 'Add New Storage',        // Added - 2018-08-30
+    'AddNewUser'           => 'Adicionar Usuário',
     'AddNewZone'           => 'Adicionar Zona',
     'Alarm'                => 'Alarme',
     'AlarmBrFrames'        => 'Imagens<br/>Alarmadas',
@@ -34,7 +36,7 @@ $SLANG = array(
     'AnalysisFPS'          => 'Analysis FPS',           // Added - 2015-07-22
     'AnalysisUpdateDelay'  => 'Analysis Update Delay',  // Added - 2015-07-23
     'Apply'                => 'Aplicar',
-    'ApplyingStateChange'  => 'Aplicando mudana de estado',
+    'ApplyingStateChange'  => 'Aplicando mudança de estado',
     'ArchArchived'         => 'Somente Arquivados',
     'ArchUnarchived'       => 'Somente Nao Arquivados',
     'Archive'              => 'Arquivar',
@@ -45,22 +47,32 @@ $SLANG = array(
     'AttrArchiveStatus'    => 'Status/Arquivamento',
     'AttrAvgScore'         => 'Maior Score',
     'AttrCause'            => 'Cause',
-    'AttrDate'             => 'Data',
-    'AttrDateTime'         => 'Data/Horario',
     'AttrDiskBlocks'       => 'Blocos de Disco',
     'AttrDiskPercent'      => 'Porcentagem de Disco',
-    'AttrDuration'         => 'Durao',
+    'AttrDiskSpace'        => 'Disk Space',             // Added - 2018-08-30
+    'AttrDuration'         => 'Duração',
+    'AttrEndDate'          => 'End Date',               // Added - 2018-08-30
+    'AttrEndDateTime'      => 'End Date/Time',          // Added - 2018-08-30
+    'AttrEndTime'          => 'End Time',               // Added - 2018-08-30
+    'AttrEndWeekday'       => 'End Weekday',            // Added - 2018-08-30
+    'AttrFilterServer'     => 'Server Filter is Running On', // Added - 2018-08-30
     'AttrFrames'           => 'Imagens',
     'AttrId'               => 'Id',
     'AttrMaxScore'         => 'Max. Score',
     'AttrMonitorId'        => 'Id do Monitor',
     'AttrMonitorName'      => 'Nome do Monitor',
+    'AttrMonitorServer'    => 'Server Monitor is Running On', // Added - 2018-08-30
     'AttrName'             => 'Nome',
     'AttrNotes'            => 'Notes',
+    'AttrStartDate'        => 'Start Date',             // Added - 2018-08-30
+    'AttrStartDateTime'    => 'Start Date/Time',        // Added - 2018-08-30
+    'AttrStartTime'        => 'Start Time',             // Added - 2018-08-30
+    'AttrStartWeekday'     => 'Start Weekday',          // Added - 2018-08-30
+    'AttrStateId'          => 'Run State',              // Added - 2018-08-30
+    'AttrStorageArea'      => 'Storage Area',           // Added - 2018-08-30
+    'AttrStorageServer'    => 'Server Hosting Storage', // Added - 2018-08-30
     'AttrSystemLoad'       => 'System Load',
-    'AttrTime'             => 'Horrio',
     'AttrTotalScore'       => 'Score Total',
-    'AttrWeekday'          => 'Dia/Semana',
     'Auto'                 => 'Auto',
     'AutoStopTimeout'      => 'Auto Stop Timeout',
     'Available'            => 'Available',              // Added - 2009-03-31
@@ -84,7 +96,7 @@ $SLANG = array(
     'BadLabelY'            => 'Label Y co-ordinate must be set to an integer of zero or more',
     'BadMaxFPS'            => 'Maximum FPS must be a positive integer or floating point value',
     'BadMotionFrameSkip'   => 'Motion Frame skip count must be an integer of zero or more',
-    'BadNameChars'         => 'Nomes devem ser caracteres alfanumricos mais hfen e underscore',
+    'BadNameChars'         => 'Nomes devem ser caracteres alfanuméricos mais hífen e underscore',
     'BadPalette'           => 'Palette must be set to a valid value', // Added - 2009-03-31
     'BadPath'              => 'Path must be set to a valid value',
     'BadPort'              => 'Port must be set to a valid number',
@@ -93,9 +105,11 @@ $SLANG = array(
     'BadRefBlendPerc'      => 'Reference blend percentage must be a positive integer',
     'BadSectionLength'     => 'Section length must be an integer of 30 or more',
     'BadSignalCheckColour' => 'Signal check colour must be a valid RGB colour string',
+    'BadSourceType'        => 'Source Type \"Web Site\" requires the Function to be set to \"Monitor\"', // Added - 2018-08-30
     'BadStreamReplayBuffer'=> 'Stream replay buffer must be an integer of zero or more',
     'BadWarmupCount'       => 'Warmup frames must be an integer of zero or more',
     'BadWebColour'         => 'Web colour must be a valid web colour string',
+    'BadWebSitePath'       => 'Please enter a complete website url, including the http:// or https:// prefix.', // Added - 2018-08-30
     'BadWidth'             => 'Width must be set to a valid value',
     'Bandwidth'            => 'Larg/Banda',
     'BandwidthHead'         => 'Bandwidth',	// This is the end of the bandwidth status on the top of the console, different in many language due to phrasing
@@ -145,7 +159,7 @@ $SLANG = array(
     'CanZoomCon'           => 'Can Zoom Continuous',
     'CanZoomRel'           => 'Can Zoom Relative',
     'Cancel'               => 'Cancelar',
-    'CancelForcedAlarm'    => 'Cancelar Alarme Forado',
+    'CancelForcedAlarm'    => 'Cancelar Alarme Forçado',
     'CaptureHeight'        => 'Altura da Captura',
     'CaptureMethod'        => 'Capture Method',         // Added - 2009-02-08
     'CapturePalette'       => 'Paleta de Captura',
@@ -159,10 +173,12 @@ $SLANG = array(
     'ChooseLogSelection'   => 'Choose a log selection', // Added - 2011-06-17
     'ChoosePreset'         => 'Choose Preset',
     'Clear'                => 'Clear',                  // Added - 2011-06-16
+    'CloneMonitor'         => 'Clone',                  // Added - 2018-08-30
     'Close'                => 'Fechar',
     'Colour'               => 'Cor',
     'Command'              => 'Command',
     'Component'            => 'Component',              // Added - 2011-06-16
+    'ConcurrentFilter'     => 'Run filter concurrently', // Added - 2018-08-30
     'Config'               => 'Config',
     'ConfiguredFor'        => 'Configurado para',
     'ConfirmDeleteEvents'  => 'Are you sure you wish to delete the selected events?',
@@ -192,10 +208,10 @@ $SLANG = array(
     'Deinterlacing'        => 'Deinterlacing',          // Added - 2015-04-18
     'Delay'                => 'Delay',                  // Added - 2015-04-18
     'Delete'               => 'Deletar',
-    'DeleteAndNext'        => 'Deletar &amp; Prx',
+    'DeleteAndNext'        => 'Deletar &amp; Próx',
     'DeleteAndPrev'        => 'Deletar &amp; Ant',
     'DeleteSavedFilter'    => 'Deletar Filtros Salvos',
-    'Description'          => 'Descrio',
+    'Description'          => 'Descrição',
     'DetectedCameras'      => 'Detected Cameras',       // Added - 2009-03-31
     'DetectedProfiles'     => 'Detected Profiles',      // Added - 2015-04-18
     'Device'               => 'Device',                 // Added - 2009-02-08
@@ -204,7 +220,7 @@ $SLANG = array(
     'DeviceNumber'         => 'Num. do Dispos.',
     'DevicePath'           => 'Device Path',
     'Devices'              => 'Devices',
-    'Dimensions'           => 'Dimenses',
+    'Dimensions'           => 'Dimensões',
     'DisableAlarms'        => 'Disable Alarms',
     'Disk'                 => 'Disco',
     'Display'              => 'Display',                // Added - 2011-01-30
@@ -220,16 +236,18 @@ $SLANG = array(
     'DonateRemindWeek'     => 'Not yet, remind again in 1 week',
     'DonateYes'            => 'Yes, I\'d like to donate now',
     'Download'             => 'Download',
+    'DownloadVideo'        => 'Download Video',         // Added - 2018-08-30
     'DuplicateMonitorName' => 'Duplicate Monitor Name', // Added - 2009-03-31
-    'Duration'             => 'Durao',
+    'Duration'             => 'Duração',
     'Edit'                 => 'Editar',
+    'EditLayout'           => 'Edit Layout',            // Added - 2018-08-30
     'Email'                => 'Email',
     'EnableAlarms'         => 'Enable Alarms',
     'Enabled'              => 'Habilitado',
     'EnterNewFilterName'   => 'Digite nome do novo filtro',
     'Error'                => 'Erro',
-    'ErrorBrackets'        => 'Por favor cheque se voc tem o mesmo numero de chaves abertas e fechadas',
-    'ErrorValidValue'      => 'Erro, por favor cheque se os campos esto corretos',
+    'ErrorBrackets'        => 'Por favor cheque se você tem o mesmo numero de chaves abertas e fechadas',
+    'ErrorValidValue'      => 'Erro, por favor cheque se os campos estão corretos',
     'Etc'                  => 'etc',
     'Event'                => 'Evento',
     'EventFilter'          => 'Filtro de Evento',
@@ -239,6 +257,7 @@ $SLANG = array(
     'Events'               => 'Eventos',
     'Exclude'              => 'Excluir',
     'Execute'              => 'Execute',
+    'Exif'                 => 'Embed EXIF data into image', // Added - 2018-08-30
     'Export'               => 'Export',
     'ExportDetails'        => 'Export Event Details',
     'ExportFailed'         => 'Export Failed',
@@ -268,8 +287,10 @@ $SLANG = array(
     'FilterExecuteEvents'  => 'Executar comando p/ resultados',
     'FilterLog'            => 'Filter log',             // Added - 2015-04-18
     'FilterMessageEvents'  => 'Enviar Mensagem dos resultados',
+    'FilterMoveEvents'     => 'Move all matches',       // Added - 2018-08-30
     'FilterPx'             => 'Px de Filtro',
     'FilterUnset'          => 'You must specify a filter width and height',
+    'FilterUpdateDiskSpace'=> 'Update used disk space', // Added - 2018-08-30
     'FilterUploadEvents'   => 'Fazer upload dos resultados',
     'FilterVideoEvents'    => 'Create video for all matches',
     'Filters'              => 'Filters',
@@ -283,7 +304,7 @@ $SLANG = array(
     'FnNone'                => 'None',            // Added 2013.08.16.
     'FnRecord'              => 'Record',            // Added 2013.08.16.
     'Focus'                => 'Focus',
-    'ForceAlarm'           => 'Forar Alarme',
+    'ForceAlarm'           => 'Forçar Alarme',
     'Format'               => 'Format',
     'Frame'                => 'Imagem',
     'FrameId'              => 'Id de Imagem',
@@ -291,9 +312,10 @@ $SLANG = array(
     'FrameSkip'            => 'Salto de Imagem',
     'Frames'               => 'Imagens',
     'Func'                 => 'Func',
-    'Function'             => 'Funo',
+    'Function'             => 'Função',
     'Gain'                 => 'Gain',
     'General'              => 'General',
+    'GenerateDownload'     => 'Generate Download',      // Added - 2018-08-30
     'GenerateVideo'        => 'Gerar Video',
     'GeneratingVideo'      => 'Gerando Video',
     'GoToZoneMinder'       => 'Ir Para ZoneMinder.com',
@@ -314,8 +336,9 @@ $SLANG = array(
     'High'                 => 'Alto',
     'HighBW'               => 'Alta&nbsp;L/B',
     'Home'                 => 'Home',
+    'Hostname'             => 'Hostname',               // Added - 2018-08-30
     'Hour'                 => 'Hora',
-    'Hue'                  => 'Saturao',
+    'Hue'                  => 'Saturação',
     'Id'                   => 'Id',
     'Idle'                 => 'Parado',
     'Ignore'               => 'Ignorar',
@@ -329,7 +352,7 @@ $SLANG = array(
     'KeyString'            => 'Key String',
     'Label'                => 'Label',
     'Language'             => 'Linguagem',
-    'Last'                 => 'ltimo',
+    'Last'                 => 'Último',
     'Layout'               => 'Layout',                 // Added - 2009-02-08
     'Level'                => 'Level',                  // Added - 2011-06-16
     'Libvlc'               => 'Libvlc',
@@ -338,6 +361,7 @@ $SLANG = array(
     'Line'                 => 'Line',                   // Added - 2011-06-16
     'LinkedMonitors'       => 'Linked Monitors',
     'List'                 => 'List',
+    'ListMatches'          => 'List Matches',           // Added - 2018-08-30
     'Load'                 => 'Carga',
     'Local'                => 'Local',
     'Log'                  => 'Log',                    // Added - 2011-06-16
@@ -383,7 +407,7 @@ $SLANG = array(
     'Message'              => 'Message',                // Added - 2011-06-16
     'MinAlarmAreaLtMax'    => 'Minimum alarm area should be less than maximum',
     'MinAlarmAreaUnset'    => 'You must specify the minimum alarm pixel count',
-    'MinBlobAreaLtMax'     => 'A area minima de blob deve ser menor do que a area mxima de blob',
+    'MinBlobAreaLtMax'     => 'A area minima de blob deve ser menor do que a area máxima de blob',
     'MinBlobAreaUnset'     => 'You must specify the minimum blob pixel count',
     'MinBlobLtMinFilter'   => 'Minimum blob area should be less than or equal to minimum filter area',
     'MinBlobsLtMax'        => 'O minimo de Blobs deve ser menor que o maximo de blobs',
@@ -424,7 +448,8 @@ $SLANG = array(
     'MonitorProbeIntro'    => 'The list below shows detected analog and network cameras and whether they are already being used or available for selection.<br/><br/>Select the desired entry from the list below.<br/><br/>Please note that not all cameras may be detected and that choosing a camera here may overwrite any values you already have configured for the current monitor.<br/><br/>', // Added - 2009-03-31
     'Monitors'             => 'Monitores',
     'Montage'              => 'Montagem',
-    'Month'                => 'Ms',
+    'MontageReview'        => 'Montage Review',         // Added - 2018-08-30
+    'Month'                => 'Mês',
     'More'                 => 'More',                   // Added - 2011-06-16
     'MotionFrameSkip'      => 'Motion Frame Skip',
     'Move'                 => 'Move',
@@ -437,7 +462,7 @@ $SLANG = array(
     'MustBeLe'             => 'deve ser menor ou igual a',
     'MustConfirmPassword'  => 'Voce deve Confirmar a senha',
     'MustSupplyPassword'   => 'Voce deve informar a senha',
-    'MustSupplyUsername'   => 'Voce deve informar nome de usurio',
+    'MustSupplyUsername'   => 'Voce deve informar nome de usuário',
     'Name'                 => 'Nome',
     'Near'                 => 'Near',
     'Network'              => 'Rede',
@@ -446,16 +471,17 @@ $SLANG = array(
     'NewLabel'             => 'New Label',
     'NewPassword'          => 'Nova Senha',
     'NewState'             => 'Novo Estado',
-    'NewUser'              => 'Novo Usurio',
-    'Next'                 => 'Prx',
-    'No'                   => 'No',
+    'NewUser'              => 'Novo Usuário',
+    'Next'                 => 'Próx',
+    'No'                   => 'Não',
     'NoDetectedCameras'    => 'No Detected Cameras',    // Added - 2009-03-31
-    'NoFramesRecorded'     => 'No h imagens gravadas neste evento',
+    'NoDetectedProfiles'   => 'No Detected Profiles',   // Added - 2018-08-30
+    'NoFramesRecorded'     => 'Não há imagens gravadas neste evento',
     'NoGroup'              => 'No Group',
     'NoSavedFilters'       => 'SemFiltrosSalvos',
-    'NoStatisticsRecorded' => 'No h estatsticas gravadas neste evento/imagem',
+    'NoStatisticsRecorded' => 'Não há estatísticas gravadas neste evento/imagem',
     'None'                 => 'Nada',
-    'NoneAvailable'        => 'Nada disponvel',
+    'NoneAvailable'        => 'Nada disponível',
     'Normal'               => 'Normal',
     'Notes'                => 'Notes',
     'NumPresets'           => 'Num Presets',
@@ -468,19 +494,22 @@ $SLANG = array(
     'OpGt'                 => 'maior que',
     'OpGtEq'               => 'maior que ou igual a',
     'OpIn'                 => 'no set',
+    'OpIs'                 => 'is',                     // Added - 2018-08-30
+    'OpIsNot'              => 'is not',                 // Added - 2018-08-30
     'OpLt'                 => 'menor que',
     'OpLtEq'               => 'menor que ou igual a',
     'OpMatches'            => 'combina',
     'OpNe'                 => 'diferente de',
-    'OpNotIn'              => 'no no set',
-    'OpNotMatches'         => 'no combina',
+    'OpNotIn'              => 'não no set',
+    'OpNotMatches'         => 'não combina',
     'Open'                 => 'Open',
-    'OptionHelp'           => 'OpoAjuda',
-    'OptionRestartWarning' => 'Reinicie o Zoneminder para que as mudanas tenham efeito',
-    'Options'              => 'Opes',
+    'OptionHelp'           => 'OpçãoAjuda',
+    'OptionRestartWarning' => 'Reinicie o Zoneminder para que as mudanças tenham efeito',
+    'OptionalEncoderParam' => 'Optional Encoder Parameters', // Added - 2018-08-30
+    'Options'              => 'Opções',
     'OrEnterNewName'       => 'ou defina novo nome',
     'Order'                => 'Order',
-    'Orientation'          => 'Orientao',
+    'Orientation'          => 'Orientação',
     'Out'                  => 'Out',
     'OverwriteExisting'    => 'Sobrescrever Existente',
     'Paged'                => 'Paginado',
@@ -490,7 +519,7 @@ $SLANG = array(
     'PanTilt'              => 'Pan/Tilt',
     'Parameter'            => 'Parametro',
     'Password'             => 'Senha',
-    'PasswordsDifferent'   => 'A nova senha e a de confirmao so diferentes',
+    'PasswordsDifferent'   => 'A nova senha e a de confirmação são diferentes',
     'Paths'                => 'Caminhos',
     'Pause'                => 'Pause',
     'Phone'                => 'Phone',
@@ -503,8 +532,8 @@ $SLANG = array(
     'PleaseWait'           => 'Por Favor Espere',
     'Plugins'              => 'Plugins',
     'Point'                => 'Point',
-    'PostEventImageBuffer' => 'Buffer de imagem ps evento',
-    'PreEventImageBuffer'  => 'Buffer de imagem pr evento',
+    'PostEventImageBuffer' => 'Buffer de imagem pós evento',
+    'PreEventImageBuffer'  => 'Buffer de imagem pré evento',
     'PreserveAspect'       => 'Preserve Aspect Ratio',
     'Preset'               => 'Preset',
     'Presets'              => 'Presets',
@@ -514,10 +543,14 @@ $SLANG = array(
     'ProfileProbeIntro'    => 'The list below shows the existing stream profiles of the selected camera .<br/><br/>Select the desired entry from the list below.<br/><br/>Please note that ZoneMinder cannot configure additional profiles and that choosing a camera here may overwrite any values you already have configured for the current monitor.<br/><br/>', // Added - 2015-04-18
     'Progress'             => 'Progress',               // Added - 2015-04-18
     'Protocol'             => 'Protocol',
+    'RTSPDescribe'         => 'Use RTSP Response Media URL', // Added - 2018-08-30
+    'RTSPTransport'        => 'RTSP Transport Protocol', // Added - 2018-08-30
     'Rate'                 => 'Vel.',
     'Real'                 => 'Real',
+    'RecaptchaWarning'     => 'Your reCaptcha secret key is invalid. Please correct it, or reCaptcha will not work', // Added - 2018-08-30
     'Record'               => 'Gravar',
-    'RefImageBlendPct'     => 'Referncia de imagem Blend %ge',
+    'RecordAudio'          => 'Whether to store the audio stream when saving an event.', // Added - 2018-08-30
+    'RefImageBlendPct'     => 'Referência de imagem Blend %ge',
     'Refresh'              => 'Atualizar',
     'Remote'               => 'Remoto',
     'RemoteHostName'       => 'Nome do host remoto',
@@ -532,24 +565,26 @@ $SLANG = array(
     'ReplayAll'            => 'All Events',
     'ReplayGapless'        => 'Gapless Events',
     'ReplaySingle'         => 'Single Event',
+    'ReportEventAudit'     => 'Audit Events Report',    // Added - 2018-08-30
     'Reset'                => 'Reset',
     'ResetEventCounts'     => 'Resetar contagem de eventos',
     'Restart'              => 'Reiniciar',
     'Restarting'           => 'Reiniciando',
-    'RestrictedCameraIds'  => 'Ids de camera proibdos',
+    'RestrictedCameraIds'  => 'Ids de camera proibídos',
     'RestrictedMonitors'   => 'Restricted Monitors',
     'ReturnDelay'          => 'Return Delay',
     'ReturnLocation'       => 'Return Location',
     'Rewind'               => 'Rewind',
-    'RotateLeft'           => 'Rotacionar  esquerda ',
-    'RotateRight'          => 'Rotacionar  direita',
+    'RotateLeft'           => 'Rotacionar à esquerda ',
+    'RotateRight'          => 'Rotacionar à direita',
     'RunLocalUpdate'       => 'Please run zmupdate.pl to update', // Added - 2011-05-25
-    'RunMode'              => 'Modo de Execuo',
-    'RunState'             => 'Estado de Execuo',
+    'RunMode'              => 'Modo de Execução',
+    'RunState'             => 'Estado de Execução',
     'Running'              => 'Rodando',
     'Save'                 => 'Salvar',
     'SaveAs'               => 'Salvar Como',
     'SaveFilter'           => 'Salvar Filtro',
+    'SaveJPEGs'            => 'Save JPEGs',             // Added - 2018-08-30
     'Scale'                => 'Tamanho',
     'Score'                => 'Score',
     'Secs'                 => 'Segs',
@@ -562,10 +597,11 @@ $SLANG = array(
     'Set'                  => 'Set',
     'SetNewBandwidth'      => 'Defina Nova L/B',
     'SetPreset'            => 'Set Preset',
-    'Settings'             => 'Configuraes',
+    'Settings'             => 'Configurações',
     'ShowFilterWindow'     => 'MostrarJanelaDeFiltros',
     'ShowTimeline'         => 'Show Timeline',
     'SignalCheckColour'    => 'Signal Check Colour',
+    'SignalCheckPoints'    => 'Signal Check Points',    // Added - 2018-08-30
     'Size'                 => 'Size',
     'SkinDescription'      => 'Change the default skin for this computer', // Added - 2011-01-30
     'Sleep'                => 'Sleep',
@@ -585,6 +621,10 @@ $SLANG = array(
     'State'                => 'Estado',
     'Stats'                => 'Status',
     'Status'               => 'Status',
+    'StatusConnected'      => 'Capturing',              // Added - 2018-08-30
+    'StatusNotRunning'     => 'Not Running',            // Added - 2018-08-30
+    'StatusRunning'        => 'Not Capturing',          // Added - 2018-08-30
+    'StatusUnknown'        => 'Unknown',                // Added - 2018-08-30
     'Step'                 => 'Step',
     'StepBack'             => 'Step Back',
     'StepForward'          => 'Step Forward',
@@ -595,7 +635,9 @@ $SLANG = array(
     'Stills'               => 'Imagens',
     'Stop'                 => 'Parar',
     'Stopped'              => 'Parado',
-    'Stream'               => 'Contnuo',
+    'StorageArea'          => 'Storage Area',           // Added - 2018-08-30
+    'StorageScheme'        => 'Scheme',                 // Added - 2018-08-30
+    'Stream'               => 'Contínuo',
     'StreamReplayBuffer'   => 'Stream Replay Image Buffer',
     'Submit'               => 'Submit',
     'System'               => 'Sistema',
@@ -614,8 +656,9 @@ $SLANG = array(
     'TimelineTip4'         => 'Use the controls below to zoom out or navigate back and forward through the time range.',              // Added 2013.08.15.
     'Timestamp'            => 'Tempo',
     'TimestampLabelFormat' => 'Formato de etiqueta de tempo',
-    'TimestampLabelX'      => 'posio de etiqueta X',
-    'TimestampLabelY'      => 'posio de  etiqueta Y',
+    'TimestampLabelSize'   => 'Font Size',              // Added - 2018-08-30
+    'TimestampLabelX'      => 'posição de etiqueta X',
+    'TimestampLabelY'      => 'posição de  etiqueta Y',
     'Today'                => 'Today',
     'Tools'                => 'Ferramentas',
     'Total'                => 'Total',                  // Added - 2011-06-16
@@ -631,35 +674,36 @@ $SLANG = array(
     'Units'                => 'Unidades',
     'Unknown'              => 'Desconhecido',
     'Update'               => 'Update',
-    'UpdateAvailable'      => 'Um update ao zoneminder est disponvel.',
-    'UpdateNotNecessary'   => 'No  necessrio update.',
+    'UpdateAvailable'      => 'Um update ao zoneminder está disponível.',
+    'UpdateNotNecessary'   => 'Não é necessário update.',
     'Updated'              => 'Updated',                // Added - 2011-06-16
     'Upload'               => 'Upload',                 // Added - 2011-08-23
     'UseFilter'            => 'Use Filtro',
-    'UseFilterExprsPost'   => '&nbsp;expresses&nbsp;de&nbsp;filtragem', // This is used at the end of the phrase 'use N filter expressions'
+    'UseFilterExprsPost'   => '&nbsp;expressões&nbsp;de&nbsp;filtragem', // This is used at the end of the phrase 'use N filter expressions'
     'UseFilterExprsPre'    => 'Use&nbsp;', // This is used at the beginning of the phrase 'use N filter expressions'
     'UsedPlugins'	   => 'Used Plugins',
-    'User'                 => 'Usurio',
-    'Username'             => 'Nome de Usurio',
-    'Users'                => 'Usurios',
+    'User'                 => 'Usuário',
+    'Username'             => 'Nome de Usuário',
+    'Users'                => 'Usuários',
     'V4L'                  => 'V4L',                    // Added - 2015-04-18
     'V4LCapturesPerFrame'  => 'Captures Per Frame',     // Added - 2015-04-18
     'V4LMultiBuffer'       => 'Multi Buffering',        // Added - 2015-04-18
     'Value'                => 'Valor',
-    'Version'              => 'Verso',
-    'VersionIgnore'        => 'Ignorar esta verso',
+    'Version'              => 'Versão',
+    'VersionIgnore'        => 'Ignorar esta versão',
     'VersionRemindDay'     => 'Lembre novamente em 1 dia',
     'VersionRemindHour'    => 'Lembre novamente em 1 hora',
-    'VersionRemindNever'   => 'Nao lembrar novas verses',
+    'VersionRemindNever'   => 'Nao lembrar novas versões',
     'VersionRemindWeek'    => 'Lembrar novamente em 1 semana',
     'Video'                => 'Video',
     'VideoFormat'          => 'Video Format',
-    'VideoGenFailed'       => 'Gerao de Vdeo falhou!',
+    'VideoGenFailed'       => 'Geração de Vídeo falhou!',
     'VideoGenFiles'        => 'Existing Video Files',
     'VideoGenNoFiles'      => 'No Video Files Found',
-    'VideoGenParms'        => 'Parametros de  gerao de vdeo',
+    'VideoGenParms'        => 'Parametros de  geração de vídeo',
     'VideoGenSucceeded'    => 'Video Generation Succeeded!',
-    'VideoSize'            => 'Tamanho do vdeo',
+    'VideoSize'            => 'Tamanho do vídeo',
+    'VideoWriter'          => 'Video Writer',           // Added - 2018-08-30
     'View'                 => 'Ver',
     'ViewAll'              => 'Ver Tudo',
     'ViewEvent'            => 'View Event',
@@ -669,18 +713,19 @@ $SLANG = array(
     'Watch'                => 'Assistir',
     'Web'                  => 'Web',
     'WebColour'            => 'Web Colour',
+    'WebSiteUrl'           => 'Website URL',            // Added - 2018-08-30
     'Week'                 => 'Semana',
     'White'                => 'White',
     'WhiteBalance'         => 'White Balance',
     'Wide'                 => 'Wide',
     'X'                    => 'X',
     'X10'                  => 'X10',
-    'X10ActivationString'  => 'String de Ativao X10',
+    'X10ActivationString'  => 'String de Ativação X10',
     'X10InputAlarmString'  => 'String de Entrada  de alarme X10',
-    'X10OutputAlarmString' => 'String de Sada de Alarme X10',
+    'X10OutputAlarmString' => 'String de Saída de Alarme X10',
     'Y'                    => 'Y',
     'Yes'                  => 'Sim',
-    'YouNoPerms'           => 'Voc no tem permisses para acessar este recurso.',
+    'YouNoPerms'           => 'Você não tem permissões para acessar este recurso.',
     'Zone'                 => 'Zona',
     'ZoneAlarmColour'      => 'Cor de Alarme (Red/Green/Blue)',
     'ZoneArea'             => 'Zone Area',
@@ -701,13 +746,13 @@ $SLANG = array(
 
 // Complex replacements with formatting and/or placements, must be passed through sprintf
 $CLANG = array(
-    'CurrentLogin'         => 'Login atual  \'%1$s\'',
+    'CurrentLogin'         => 'Login atual é \'%1$s\'',
     'EventCount'           => '%1$s %2$s', // For example '37 Events' (from Vlang below)
-    'LastEvents'           => 'ltimos %1$s %2$s', // For example 'Last 37 Events' (from Vlang below)
-    'LatestRelease'        => 'A ltima verso  v%1$s, voc tem v%2$s.',
+    'LastEvents'           => 'Últimos %1$s %2$s', // For example 'Last 37 Events' (from Vlang below)
+    'LatestRelease'        => 'A Última versão é v%1$s, você tem v%2$s.',
     'MonitorCount'         => '%1$s %2$s', // For example '4 Monitors' (from Vlang below)
-    'MonitorFunction'      => 'Monitor %1$s Funco',
-    'RunningRecentVer'     => 'Voc est usando a verso mais recente do ZoneMinder, v%s.',
+    'MonitorFunction'      => 'Monitor %1$s Funcção',
+    'RunningRecentVer'     => 'Você está usando a versão mais recente do ZoneMinder, v%s.',
     'VersionMismatch'      => 'Version mismatch, system is version %1$s, database is %2$s.', // Added - 2011-05-25
 );
 
