@@ -1,4 +1,4 @@
 var connKey = '<?php echo $connkey ?>';
-var monitorUrl = '<?php echo ( $monitor->Server()->Url() ) ?>';
+var monitorUrl = '<?php echo ( $monitor->UrlToIndex() ) ?>';
 var CMD_QUIT = <?php echo CMD_QUIT ?>;
 
