@@ -23,7 +23,7 @@ xhtmlHeaders(__FILE__, translate('LoggingIn') );
 <body>
   <div id="page">
     <div id="header">
-      <h1>ZoneMinder <?php echo translate('Login') ?></h1>
+      <h1><?php echo ZM_WEB_TITLE . ' ' . translate('Login') ?></h1>
     </div>
     <div id="content">
       <h2><?php echo translate('LoggingIn') ?></h2>
